@@ -1,5 +1,5 @@
 #
-# $Id: Virustotal.pm,v e5e3576f73a3 2015/11/10 09:17:44 gomor $
+# $Id: Virustotal.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # api::virustotal Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik::Client::Rest);
 
 sub brik_properties {
    return {
-      revision => '$Revision: e5e3576f73a3 $',
-      tags => [ qw(unstable rest api virustotal domain virtualhost) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable rest domain virtualhost) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          apikey => [ qw(apikey) ],
          output_mode => [ qw(json|xml) ],
@@ -22,10 +24,10 @@ sub brik_properties {
          output_mode => 'json',
       },
       commands => {
-         check_resource => [ qw(hash) ],
-         file_report => [ qw(hash) ],
-         ipv4_address_report => [ qw(ipv4_address) ],
-         domain_report => [ qw(domain) ],
+         check_resource => [ qw(hash apikey|OPTIONAL) ],
+         file_report => [ qw(hash apikey|OPTIONAL) ],
+         ipv4_address_report => [ qw(ipv4_address apikey|OPTIONAL) ],
+         domain_report => [ qw(domain apikey|OPTIONAL) ],
          subdomain_list => [ qw(domain) ],
          hosted_domains => [ qw(ipv4_address) ],
       },
@@ -38,15 +40,11 @@ sub brik_properties {
 
 sub check_resource {
    my $self = shift;
-   my ($resource) = @_;
+   my ($resource, $apikey) = @_;
 
-   my $apikey = $self->apikey;
-   if (! defined($apikey)) {
-      return $self->log->error($self->brik_help_set('apikey'));
-   }
-   if (! defined($resource)) {
-      return $self->log->error($self->brik_help_run('check_resource'));
-   }
+   $apikey ||= $self->apikey;
+   $self->brik_help_run_undef_arg('check_resource', $resource) or return;
+   $self->brik_help_run_undef_arg('check_resource', $apikey) or return;
 
    my $r = $self->post({ apikey => $apikey, resource => $resource },
       'https://www.virustotal.com/vtapi/v2/file/rescan')
@@ -65,15 +63,11 @@ sub check_resource {
 
 sub file_report {
    my $self = shift;
-   my ($resource) = @_;
+   my ($resource, $apikey) = @_;
 
-   my $apikey = $self->apikey;
-   if (! defined($apikey)) {
-      return $self->log->error($self->brik_help_set('apikey'));
-   }
-   if (! defined($resource)) {
-      return $self->log->error($self->brik_help_run('file_report'));
-   }
+   $apikey ||= $self->apikey;
+   $self->brik_help_run_undef_arg('file_report', $resource) or return;
+   $self->brik_help_run_undef_arg('file_report', $apikey) or return;
 
    my $r = $self->post({ apikey => $apikey, resource => $resource },
       'https://www.virustotal.com/vtapi/v2/file/report')
@@ -92,15 +86,11 @@ sub file_report {
 
 sub ipv4_address_report {
    my $self = shift;
-   my ($ipv4_address) = @_;
+   my ($ipv4_address, $apikey) = @_;
 
-   my $apikey = $self->apikey;
-   if (! defined($apikey)) {
-      return $self->log->error($self->brik_help_set('apikey'));
-   }
-   if (! defined($ipv4_address)) {
-      return $self->log->error($self->brik_help_run('ipv4_address_report'));
-   }
+   $apikey ||= $self->apikey;
+   $self->brik_help_run_undef_arg('ipv4_address_report', $ipv4_address) or return;
+   $self->brik_help_run_undef_arg('ipv4_address_report', $apikey) or return;
 
    my $r = $self->get('https://www.virustotal.com/vtapi/v2/ip-address/report?apikey='
       .$apikey.'&ip='.$ipv4_address)
@@ -119,15 +109,11 @@ sub ipv4_address_report {
 
 sub domain_report {
    my $self = shift;
-   my ($domain) = @_;
+   my ($domain, $apikey) = @_;
 
-   my $apikey = $self->apikey;
-   if (! defined($apikey)) {
-      return $self->log->error($self->brik_help_set('apikey'));
-   }
-   if (! defined($domain)) {
-      return $self->log->error($self->brik_help_run('domain_report'));
-   }
+   $apikey ||= $self->apikey;
+   $self->brik_help_run_undef_arg('domain_report', $domain) or return;
+   $self->brik_help_run_undef_arg('domain_report', $apikey) or return;
 
    my $r = $self->get('https://www.virustotal.com/vtapi/v2/domain/report?apikey='
       .$apikey.'&domain='.$domain)
@@ -148,9 +134,7 @@ sub subdomain_list {
    my $self = shift;
    my ($domain) = @_;
 
-   if (! defined($domain)) {
-      return $self->log->error($self->brik_help_run('subdomain_list'));
-   }
+   $self->brik_help_run_undef_arg('subdomain_list', $domain) or return;
 
    my $r = $self->domain_report($domain) or return;
 
@@ -165,9 +149,7 @@ sub hosted_domains {
    my $self = shift;
    my ($ipv4_address) = @_;
 
-   if (! defined($ipv4_address)) {
-      return $self->log->error($self->brik_help_run('hosted_domains'));
-   }
+   $self->brik_help_run_undef_arg('hosted_domains', $ipv4_address) or return;
 
    my $r = $self->ipv4_address_report($ipv4_address) or return;
 
@@ -191,7 +173,7 @@ Metabrik::Api::Virustotal - api::virustotal Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
