@@ -1,5 +1,5 @@
 #
-# $Id: Dns.pm,v 259de0608971 2015/11/10 17:51:32 gomor $
+# $Id: Dns.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # audit::dns Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 259de0608971 $',
-      tags => [ qw(unstable audit dns) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          nameserver => [ qw(nameserver|$nameserver_list) ],
          domainname => [ qw(domainname) ],
@@ -22,10 +24,11 @@ sub brik_properties {
          rtimeout => 2,
          nameserver => '127.0.0.1',
       },
+         # XXX: version should use network::dns version_bind Command
       commands => {
          version => [ qw(nameserver|$nameserver_list|OPTIONAL) ],
          recursion => [ qw(nameserver|$nameserver_list|OPTIONAL) ],
-         axfr => [ qw(nameserver|$nameserver_list|OPTIONAL domainname|$domainname_list|OPTIONAL) ],
+         axfr => [ qw(nameserver|$nameserver_list domainname|$domainname_list) ],
          all => [ qw(nameserver|$nameserver_list|OPTIONAL domainname|$domainname_list|OPTIONAL) ],
       },
       require_modules => {
@@ -39,12 +42,12 @@ sub version {
    my ($nameserver) = @_;
 
    $nameserver ||= $self->nameserver;
-   if (! defined($nameserver)) {
-      return $self->log->error($self->brik_help_run('version'));
-   }
+   $self->brik_help_run_undef_arg('version', $nameserver) or return;
+   my $ref = $self->brik_help_run_invalid_arg('version', $nameserver, 'ARRAY', 'SCALAR')
+      or return;
 
    my $result = {};
-   if (ref($nameserver) eq 'ARRAY') {
+   if ($ref eq 'ARRAY') {
       for (@$nameserver) {
          my $r = $self->version($_);
          for (keys %$r) { $result->{$_} = $r->{$_} }
@@ -80,12 +83,12 @@ sub recursion {
    my ($nameserver) = @_;
 
    $nameserver ||= $self->nameserver;
-   if (! defined($nameserver)) {
-      return $self->log->error($self->brik_help_run('recursion'));
-   }
+   $self->brik_help_run_undef_arg('recursion', $nameserver) or return;
+   my $ref = $self->brik_help_run_invalid_arg('recursion', $nameserver, 'ARRAY', 'SCALAR')
+      or return;
 
    my $result = {};
-   if (ref($nameserver)) {
+   if ($ref eq 'ARRAY') {
       for (@$nameserver) {
          my $r = $self->recursion($_);
          for (keys %$r) { $result->{$_} = $r->{$_} }
@@ -119,15 +122,13 @@ sub axfr {
 
    $nameserver ||= $self->nameserver;
    $domainname ||= $self->domainname;
-   if (! defined($nameserver)) {
-      return $self->log->error($self->brik_help_run('nameserver'));
-   }
-   if (! defined($domainname)) {
-      return $self->log->error($self->brik_help_run('nameserver'));
-   }
+   $self->brik_help_run_undef_arg('axfr', $nameserver) or return;
+   my $ref = $self->brik_help_run_invalid_arg('axfr', $nameserver, 'ARRAY', 'SCALAR')
+      or return;
+   $self->brik_help_run_undef_arg('axfr', $domainname) or return;
 
    my $result = {};
-   if (ref($nameserver) eq 'ARRAY') {
+   if ($ref eq 'ARRAY') {
       for (@$nameserver) {
          my $r = $self->axfr($_);
          for (keys %$r) { $result->{$_} = $r->{$_} }
@@ -144,7 +145,10 @@ sub axfr {
       ) or return $self->log->error("axfr: Net::DNS::Resolver::new failed");
 
       my $axfr_allowed = 0;
-      my @res = $dns->axfr;
+      my @res;
+      eval {
+         @res = $dns->axfr;  # May fail with 'improperly terminated AXFR'
+      };
       if (@res) {
          $axfr_allowed = 1;
       }
@@ -183,7 +187,7 @@ Metabrik::Audit::Dns - audit::dns Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
