@@ -1,5 +1,5 @@
 #
-# $Id: Https.pm,v 1cb13feea4e0 2015/03/08 11:51:58 gomor $
+# $Id: Https.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # audit::https Brik
 #
@@ -11,14 +11,19 @@ use base qw(Metabrik::Shell::Command);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cb13feea4e0 $',
-      tags => [ qw(unstable https audit ssl openssl) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable ssl openssl) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          uri => [ qw(uri) ],
       },
       commands => {
          check_ssl3_support => [ qw(uri|OPTIONAL) ],
       },
+      require_modules => {
+         'Metabrik::String::Uri' => [ ],
+      },
       require_binaries => {
          'printf' => [ ],
          'openssl' => [ ],
@@ -26,16 +31,7 @@ sub brik_properties {
    };
 }
 
-sub brik_use_properties {
-   my $self = shift;
-
-   return {
-      attributes_default => {
-         uri => $self->global->uri,
-      },
-   };
-}
-
+#
 # Poodle: http://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2014-3566
 #
 sub check_ssl3_support {
@@ -43,18 +39,15 @@ sub check_ssl3_support {
    my ($uri) = @_;
 
    $uri ||= $self->uri;
-   if (! defined($uri)) {
-      return $self->log->error($self->brik_help_run('check_ssl3_support'));
-   }
+   $self->brik_help_run_undef_arg('check_ssl3_support', $uri) or return;
 
    if ($uri !~ /^https:\/\//) {
       return $self->log->error("check_ssl3_support: uri [$uri] invalid format");
    }
 
-   my $string_uri = Metabrik::String::Uri->new_from_brik($self) or return;
+   my $su = Metabrik::String::Uri->new_from_brik_init($self) or return;
 
-   my $hash = $string_uri->parse($uri)
-      or return $self->log->error("check_ssl3_support: parse failed");
+   my $hash = $su->parse($uri) or return;
 
    my $host = $hash->{host};
    my $port = $hash->{port};
@@ -64,8 +57,7 @@ sub check_ssl3_support {
    $self->as_array(1);
    $self->as_matrix(0);
    $self->capture_stderr(1);
-   my $buf = $self->capture($cmd)
-      or return $self->log->error("check_ssl3_support: capture failed");
+   my $buf = $self->capture($cmd) or return;
 
    my $check = {
       ssl_version3_support => 1,
@@ -92,7 +84,7 @@ Metabrik::Audit::Https - audit::https Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
