@@ -1,5 +1,5 @@
 #
-# $Id: Tool.pm,v 57fc7992fc3a 2016/10/05 05:25:58 gomor $
+# $Id: Tool.pm,v b5a7d96de9f1 2016/10/11 06:17:23 gomor $
 #
 # brik::tool Brik
 #
@@ -11,14 +11,13 @@ use base qw(Metabrik::Shell::Command);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 57fc7992fc3a $',
+      revision => '$Revision: b5a7d96de9f1 $',
       tags => [ qw(unstable program) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          datadir => [ qw(datadir) ],
          repository => [ qw(Repository) ],
-         _done => [ qw(INTERNAL) ],  # Used to stored already recursively processed stuff
       },
       attributes_default => {
          use_pager => 1,
@@ -44,9 +43,12 @@ sub brik_properties {
          update => [ ],
          test_repository => [ ],
          view_brik_source => [ qw(Brik) ],
+         get_brik_module_file => [ qw(Brik directory_list|OPTIONAL) ],
+         clone => [ qw(Brik Repository|OPTIONAL) ],
       },
       require_modules => {
          'Metabrik::Devel::Mercurial' => [ ],
+         'Metabrik::File::Find' => [ ],
          'Metabrik::File::Text' => [ ],
          'Metabrik::Perl::Module' => [ ],
          'Metabrik::System::File' => [ ],
@@ -277,42 +279,32 @@ sub get_brik_hierarchy_recursive {
 
    $self->brik_help_run_undef_arg('get_brik_hierarchy_recursive', $brik) or return;
 
-   # XXX: rewrite using get_brik_hierarchy + get_require_briks
-   # get_require_briks_recursive works OK
+   my $hierarchy = {};
 
-   # We first gather our own Brik hierarchy
-   #my %hierarchy = ();
-   if (exists($self->{_done}{$brik})) {
-      #return;
-      return [ sort { $a cmp $b } keys %{$self->{_done}} ];
+   # We first gather the provided Brik hierarchy
+   my $provided = $self->get_brik_hierarchy($brik) or return;
+   for (@$provided) {
+      $self->debug && $self->log->debug("get_brik [$_]");
+      $hierarchy->{$_}++;
    }
 
-   my $mine = $self->get_brik_hierarchy($brik) or return;
-   $self->{_done}{$brik}++;
-   for (@$mine) {
-      $self->log->info("get_brik [$_]");
-      #$hierarchy{$_}++;
-      $self->{_done}{$_}++;
+   # And required Briks hierarchy
+   my $required = $self->get_require_briks($brik) or return;
+   for (@$required) {
+      $self->debug && $self->log->debug("get_require [$_]");
+      $hierarchy->{$_}++;
    }
 
-   # Then we search for all required Briks recursively
-   my $require_briks = $self->get_require_briks($brik) or return;
-   for my $this (@$require_briks) {
-      #if (! exists($hierarchy{$this})) {
-      if (! exists($self->{_done}{$this})) {
-         $self->log->info("require_brik [$this]");
-         my $this_hierarchy = $self->get_brik_hierarchy_recursive($this) or next;
-         #$hierarchy{$this}++;
-         $self->{_done}{$this}++;
-         for (@$this_hierarchy) {
-            #$hierarchy{$_}++;
-            $self->{_done}{$_}++;
-         }
+   # Then we search for complete hierarchy recursively
+   for my $this (keys %$hierarchy) {
+      next if $this eq $brik;  # Skip the provided one.
+      my $new = $self->get_brik_hierarchy_recursive($this) or return;
+      for (@$new) {
+         $hierarchy->{$_}++;
       }
    }
 
-   #return [ sort { $a cmp $b } keys %hierarchy ];
-   return [ sort { $a cmp $b } keys %{$self->{_done}} ];
+   return [ sort { $a cmp $b } keys %$hierarchy ];
 }
 
 sub install_all_need_packages {
@@ -647,12 +639,7 @@ sub update_repository {
    $pm->clean($repository) or return;
    $pm->build($repository) or return;
    $pm->test($repository) or return;
-
-   # If we define the core::global repository Attribute, we use that as 
-   # a local repository. We will not install Metabrik::Repository in that case.
-   if (! defined($self->global->repository)) {
-      $pm->install($repository) or return;
-   }
+   $pm->install($repository) or return;
 
    $self->execute("cat $repository/UPDATING");
 
@@ -722,6 +709,102 @@ sub view_brik_source {
    return $self->system($cmd);
 }
 
+sub get_brik_module_file {
+   my $self = shift;
+   my ($brik, $inc) = @_;
+
+   $self->brik_help_run_undef_arg('get_brik_module_file', $brik) or return;
+   my @toks = split('::', $brik);
+   if (@toks < 2 || @toks > 3) {
+      return $self->log->error("get_brik_module_file: invalid Brik format [$brik]");
+   }
+
+   # If directories are not given, we use the default one
+   if (! defined($inc)) {
+      $inc = [ @INC ];
+   }
+
+   my $repository = $self->global->repository;
+
+   my $name = $toks[-1];
+   $name = ucfirst($name);
+   $name .= '\.pm';
+
+   my $file = 'undef';
+   my $ff = Metabrik::File::Find->new_from_brik_init($self) or return;
+   for my $directory (@$inc) {
+      next if ! -d $directory; # Skip if directory does not exists
+
+      my $list = $ff->files($directory, "^$name\$") or return;
+      for my $this (@$list) {
+         my $this_brik = $this;
+         $this_brik =~ s{^$directory/Metabrik/}{};
+         $this_brik =~ s{/}{::}g;
+         $this_brik =~ s{\.pm$}{}g;
+         $this_brik = lc($this_brik);
+         if ($this_brik eq $brik) {
+            $file = $this;
+            last;
+         }
+      }
+
+      if ($file ne 'undef') {
+         last;
+      }
+   }
+
+   return $file;
+}
+
+sub clone {
+   my $self = shift;
+   my ($brik, $repository) = @_;
+
+   $repository ||= $self->global->repository;
+   $self->brik_help_run_undef_arg('clone', $brik) or return;
+
+   my @directories = ();
+   for (@INC) {
+      next if $_ eq $repository;  # Skip local repository
+      push @directories, $_;
+   }
+
+   my $module_file = $self->get_brik_module_file($brik, \@directories) or return;
+   if ($module_file eq 'undef') {
+      $self->log->error("clone: unable to find file name matching Brik [$brik]");
+   }
+
+   $self->log->verbose("clone: found Brik [$brik] to clone from module file [$module_file]");
+
+   my @toks = split('::', $brik);
+   my $file = '';
+   for (@toks) {
+      $_ = ucfirst($_);
+      $file .= "$_/";
+   }
+   $file =~ s{/$}{.pm};
+
+   my $src_file = $module_file;
+   my $dst_file = $repository.'/lib/Metabrik/'.$file;
+   (my $dst_mkdir = $dst_file) =~ s{/[^/]+$}{};
+
+   $self->debug && $self->log->debug("clone: src[$src_file] dst[$dst_file]");
+   $self->debug && $self->log->debug("clone: mkdir[$dst_mkdir]");
+
+   if (-f $dst_file) {
+      return $self->log->error("clone: destination file [$dst_file] already exists");
+   }
+
+   my $sf = Metabrik::System::File->new_from_brik_init($self) or return;
+   $sf->mkdir($dst_mkdir) or return;
+   $sf->copy($src_file, $dst_file) or return;
+   $sf->chmod($dst_file, '644') or return;
+
+   $self->context->update_available or return;
+
+   return $dst_file;
+}
+
 1;
 
 __END__
