@@ -1,5 +1,5 @@
 #
-# $Id: Query.pm,v 1fc45b781411 2016/04/15 16:12:18 gomor $
+# $Id: Query.pm,v 7ece15bd5955 2016/04/16 15:16:53 gomor $
 #
 # client::elasticsearch::query Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Client::Elasticsearch);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1fc45b781411 $',
+      revision => '$Revision: 7ece15bd5955 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -36,7 +36,7 @@ sub brik_properties {
          get_query_result_took => [ qw($query_result) ],
          term => [ qw(kv index|OPTIONAL type|OPTIONAL) ],
          wildcard => [ qw(kv index|OPTIONAL type|OPTIONAL) ],
-         range => [ qw(kv_from kv_to value index|OPTIONAL type|OPTIONAL) ],
+         range => [ qw(kv_from kv_to index|OPTIONAL type|OPTIONAL) ],
          top => [ qw(kv_count index|OPTIONAL type|OPTIONAL) ],
          top_match => [ qw(kv_count kv_match index|OPTIONAL type|OPTIONAL) ],
       },
@@ -167,8 +167,12 @@ sub term {
 
    my $q = {
       query => {
-         term => {
-            $key => $value,
+         constant_score => { 
+            filter => {
+               term => {
+                  $key => $value,
+               },
+            },
          },
       },
    };
@@ -195,9 +199,13 @@ sub wildcard {
 
    my $q = {
       query => {
-         wildcard => {
-            $key => $value,
-         },
+         #constant_score => {  # Does not like constant_score
+            #filter => {
+               wildcard => {
+                  $key => $value,
+               },
+            #},
+         #},
       },
    };
 
@@ -308,9 +316,13 @@ sub top_match {
 
    my $q = {
       query => {
-         match => {
-            $key_match => $value_match,
-         },
+         #constant_score => {   # Does not like constant_score
+            #filter => {
+               match => {
+                  $key_match => $value_match,
+               },
+            #},
+         #},
       },
       aggs => {
          top_values => {
