@@ -1,5 +1,5 @@
 #
-# $Id: Twitter.pm,v 616178e78f07 2015/10/17 16:55:47 gomor $
+# $Id: Twitter.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # client::twitter Brik
 #
@@ -11,10 +11,12 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 616178e78f07 $',
-      tags => [ qw(unstable client twitter) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       commands => {
-         connect => [ qw(consumer_key consumer_secret access_token access_token_secret) ],
+         connect => [ qw(consumer_key|OPTIONAL consumer_secret|OPTIONAL access_token|OPTIONAL access_token_secret|OPTIONAL) ],
          tweet => [ qw(message) ],
       },
       attributes => {
@@ -44,19 +46,14 @@ sub connect {
    $consumer_secret ||= $self->consumer_secret;
    $access_token ||= $self->access_token;
    $access_token_secret ||= $self->access_token_secret;
+   $self->brik_help_run_undef_arg('connect', $consumer_key) or return;
+   $self->brik_help_run_undef_arg('connect', $consumer_secret) or return;
+   $self->brik_help_run_undef_arg('connect', $access_token) or return;
+   $self->brik_help_run_undef_arg('connect', $access_token_secret) or return;
 
-   if (! defined($consumer_key)) {
-      return $self->log->error($self->brik_help_run('tweet'));
-   }
-   if (! defined($consumer_secret)) {
-      return $self->log->error($self->brik_help_run('tweet'));
-   }
-   if (! defined($access_token)) {
-      return $self->log->error($self->brik_help_run('tweet'));
-   }
-   if (! defined($access_token_secret)) {
-      return $self->log->error($self->brik_help_run('tweet'));
-   }
+   # Without that, we got:
+   # "500 Can't connect to api.twitter.com:443 (Crypt-SSLeay can't verify hostnames)"
+   $ENV{'PERL_LWP_SSL_VERIFY_HOSTNAME'} = 0;
 
    my $nt;
    eval {
@@ -83,9 +80,7 @@ sub tweet {
    my $self = shift;
    my ($message) = @_;
 
-   if (! defined($message)) {
-      return $self->log->error($self->brik_help_run('tweet'));
-   }
+   $self->brik_help_run_undef_arg('tweet', $message) or return;
 
    my $nt = $self->net_twitter;
    if (! defined($nt)) {
@@ -117,7 +112,7 @@ Metabrik::Client::Twitter - client::twitter Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
