@@ -1,5 +1,5 @@
 #
-# $Id: Udp.pm,v 887d85a7f604 2015/11/12 14:44:58 gomor $
+# $Id: Udp.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # client::udp Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik::Client::Tcp);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 887d85a7f604 $',
-      tags => [ qw(unstable client udp socket netcat) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable socket netcat) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          host => [ qw(host) ],
          port => [ qw(port) ],
@@ -44,12 +46,8 @@ sub connect {
 
    $host ||= $self->host;
    $port ||= $self->port;
-   if (! defined($host)) {
-      return $self->log->error($self->brik_help_run('connect'));
-   }
-   if (! defined($port)) {
-      return $self->log->error($self->brik_help_run('connect'));
-   }
+   $self->brik_help_run_undef_arg('connect', $host) or return;
+   $self->brik_help_run_undef_arg('connect', $port) or return;
 
    my $context = $self->context;
 
@@ -95,14 +93,12 @@ sub write {
    my $self = shift;
    my ($data, $host, $port) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('write'));
-   }
-
    if (! $self->is_connected) {
       return $self->log->error("write: not connected");
    }
 
+   $self->brik_help_run_undef_arg('write', $data) or return;
+
    my $socket = $self->_socket;
 
    eval {
@@ -126,7 +122,7 @@ Metabrik::Client::Udp - client::udp Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
