@@ -1,5 +1,5 @@
 #
-# $Id: Www.pm,v ae4d13e0fd61 2016/04/02 12:37:00 gomor $
+# $Id: Www.pm,v fc658e60fb76 2016/10/08 15:24:49 gomor $
 #
 # client::www Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: ae4d13e0fd61 $',
+      revision => '$Revision: fc658e60fb76 $',
       tags => [ qw(unstable browser http javascript screenshot) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -26,7 +26,7 @@ sub brik_properties {
          timeout => [ qw(0|1) ],
          rtimeout => [ qw(timeout) ],
          add_headers => [ qw(http_headers_hash) ],
-         do_eval_javascript => [ qw(0|1) ],
+         do_javascript => [ qw(0|1) ],
          _client => [ qw(object|INTERNAL) ],
          _last => [ qw(object|INTERNAL) ],
       },
@@ -36,7 +36,7 @@ sub brik_properties {
          timeout => 0,
          rtimeout => 10,
          add_headers => {},
-         do_eval_javascript => 0,
+         do_javascript => 0,
       },
       commands => {
          install => [ ], # Inherited
@@ -57,8 +57,7 @@ sub brik_properties {
          links => [ ],
          trace_redirect => [ qw(uri|OPTIONAL) ],
          screenshot => [ qw(uri output) ],
-         eval_javascript => [ qw(js uri) ],
-         get_javascript => [ qw(uri) ],
+         eval_javascript => [ qw(js) ],
          info => [ qw(uri|OPTIONAL) ],
          mirror => [ qw(url|$url_list output|OPTIONAL datadir|OPTIONAL) ],
          parse => [ qw(html) ],
@@ -74,16 +73,19 @@ sub brik_properties {
          'LWP::UserAgent::ProgressAny' => [ ],
          'HTTP::Request' => [ ],
          'WWW::Mechanize' => [ ],
-         'WWW::Mechanize::PhantomJS' => [ ],
          'Metabrik::File::Write' => [ ],
          'Metabrik::Client::Ssl' => [ ],
          'Metabrik::System::File' => [ ],
       },
+      optional_modules => {
+         'WWW::Mechanize::PhantomJS' => [ ],
+      },
       optional_binaries => {
          phantomjs => [ ],
       },
       need_packages => {
          ubuntu => [ qw(libssl-dev phantomjs) ],
+         debian => [ qw(libssl-dev phantomjs) ],
       },
    };
 }
@@ -115,13 +117,13 @@ sub create_user_agent {
    $ENV{PERL_NET_HTTPS_SSL_SOCKET_CLASS} = 'Net::SSL';
 
    my $mechanize = 'WWW::Mechanize';
-   if ($self->do_eval_javascript) {
+   if ($self->do_javascript) {
       if ($self->brik_has_module('WWW::Mechanize::PhantomJS')
       &&  $self->brik_has_binary('phantomjs')) {
          $mechanize = 'WWW::Mechanize::PhantomJS';
       }
       else {
-         return $self->log->error("create_user_agent: module [WWW::Mechanize::PhantomJS] not found, cannot do_eval_javascript");
+         return $self->log->error("create_user_agent: module [WWW::Mechanize::PhantomJS] not found, cannot do_javascript");
       }
    }
 
@@ -212,7 +214,14 @@ sub _method {
    my %response = ();
    $response{code} = $response->code;
    if (! $self->ignore_content) {
-      $response{content} = $response->decoded_content;
+      if ($self->do_javascript) {
+         # decoded_content method is available in WWW::Mechanize::PhantomJS
+         # but is available in HTTP::Request response otherwise.
+         $response{content} = $client->decoded_content;
+      }
+      else {
+         $response{content} = $response->decoded_content;
+      }
    }
 
    my $headers = $response->headers;
@@ -296,8 +305,14 @@ sub content {
       return $self->log->error("content: you have to execute a request first");
    }
 
-   #return $last->decoded_content;
-   return $last->content;
+   if ($self->do_javascript) {
+      # decoded_content method is available in WWW::Mechanize::PhantomJS
+      # but is available in HTTP::Request response otherwise.
+      my $client = $self->_client;
+      return $client->decoded_content;
+   }
+
+   return $last->decoded_content;
 }
 
 sub save_content {
@@ -480,59 +495,22 @@ sub screenshot {
 
 sub eval_javascript {
    my $self = shift;
-   my ($js, $uri) = @_;
+   my ($js) = @_;
 
    $self->brik_help_run_undef_arg('eval_javascript', $js) or return;
-   $self->brik_help_run_undef_arg('eval_javascript', $uri) or return;
 
    # Perl module Wight may also be an option.
 
    if ($self->brik_has_module('WWW::Mechanize::PhantomJS')
    &&  $self->brik_has_binary('phantomjs')) {
-      my $mech = WWW::Mechanize::PhantomJS->new
+      my $mech = WWW::Mechanize::PhantomJS->new(launch_arg => ['ghostdriver/src/main.js'])
          or return $self->log->error("eval_javascript: PhantomJS failed");
 
-      my $get = $mech->get($uri)
-         or return $self->log->error("eval_javascript: get uri [$uri] failed");
-      if (! $get->is_success) {
-         return $self->log->error("eval_javascript: error from GET: [".$get->status_line."]");
-      }
-
       return $mech->eval_in_page($js);
    }
 
-   return $self->log->error("eval_javascript: optional module [WWW::Mechanize::PhantomJS] and optional binary [phantomjs] are not available");
-}
-
-sub get_javascript {
-   my $self = shift;
-   my ($uri) = @_;
-
-   $self->brik_help_run_undef_arg('get_javascript', $uri) or return;
-
-   if ($self->brik_has_module('WWW::Mechanize::PhantomJS')
-   &&  $self->brik_has_binary('phantomjs')) {
-      my $mech = WWW::Mechanize::PhantomJS->new
-         or return $self->log->error("get_javascript: PhantomJS failed");
-
-      my $get = $mech->get($uri)
-         or return $self->log->error("get_javascript: get uri [$uri] failed");
-      if (! $get->is_success) {
-         return $self->log->error("get_javascript: error from GET: [".$get->status_line."]");
-      }
-
-      my $r = {};
-      $r->{code} = $get->code;
-      $r->{content} = $mech->decoded_content;
-
-      my $headers = $get->headers;
-      $r->{headers} = { map { $_ => $headers->{$_} } keys %$headers };
-      delete $r->{headers}->{'::std_case'};
-
-      return $r;
-   }
-
-   return $self->log->error("get_javascript: optional module [WWW::Mechanize::PhantomJS] and optional binary [phantomjs] are not available");
+   return $self->log->error("eval_javascript: optional module [WWW::Mechanize::PhantomJS] ".
+      "and optional binary [phantomjs] are not available");
 }
 
 sub info {
