@@ -1,5 +1,5 @@
 #
-# $Id: Gpg.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Gpg.pm,v fc658e60fb76 2016/10/08 15:24:49 gomor $
 #
 # crypto::gpg Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
+      revision => '$Revision: fc658e60fb76 $',
       tags => [ qw(unstable pgp gnupg) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -60,7 +60,8 @@ sub brik_properties {
          'rngd' => [ ],
       },
       need_packages => {
-         'ubuntu' => [ qw(rng-tools) ],
+         ubuntu => [ qw(rng-tools) ],
+         debian => [ qw(rng-tools) ],
       },
    };
 }
