@@ -1,5 +1,5 @@
 #
-# $Id: Nvd.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Nvd.pm,v 6391b00ed43b 2016/01/26 20:00:14 gomor $
 #
 # database::nvd Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Client::Www);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
+      revision => '$Revision: 6391b00ed43b $',
       tags => [ qw(unstable cve cpe nist) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -78,8 +78,8 @@ sub update {
       (my $xml = $resource->{xml}) =~ s/NAME/Recent/;
       my $output = "$datadir/$gz";
       $self->mirror($uri, $gz, $datadir) or return;
-      $fc->gunzip($output, $xml, $datadir) or return;
-      return $datadir.'/'.$xml;
+      my $files = $fc->uncompress($output, $xml, $datadir) or return;
+      return $files->[0];
    }
    elsif ($type eq 'modified') {
       (my $uri = $resource->{uri}) =~ s/NAME/Modified/;
@@ -87,8 +87,8 @@ sub update {
       (my $xml = $resource->{xml}) =~ s/NAME/Modified/;
       my $output = "$datadir/$gz";
       $self->mirror($uri, $gz, $datadir) or return;
-      $fc->gunzip($output, $xml, $datadir) or return;
-      return $datadir.'/'.$xml;
+      my $files = $fc->uncompress($output, $xml, $datadir) or return;
+      return $files->[0];
    }
    elsif ($type eq 'others') {
       my @output = ();
@@ -98,8 +98,8 @@ sub update {
          (my $xml = $resource->{xml}) =~ s/NAME/$year/;
          my $output = "$datadir/$gz";
          $self->mirror($uri, $gz, $datadir) or return;
-         $fc->gunzip($output, $xml, $datadir) or return;
-         push @output, $datadir.'/'.$xml;
+         my $files = $fc->uncompress($output, $xml, $datadir) or next;
+         push @output, @$files;
       }
       return \@output;
    }
