@@ -1,5 +1,5 @@
 #
-# $Id: Rir.pm,v f86a021f7e5f 2015/01/24 17:03:49 gomor $
+# $Id: Rir.pm,v e22cd1acb782 2016/04/06 17:56:05 gomor $
 #
 # database::rir Brik
 #
@@ -14,8 +14,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: f86a021f7e5f $',
-      tags => [ qw(unstable database rir as country subnet) ],
+      revision => '$Revision: e22cd1acb782 $',
+      tags => [ qw(unstable as country subnet) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          datadir => [ qw(datadir) ],
          input => [ qw(input.rir) ],
@@ -30,8 +32,9 @@ sub brik_properties {
          ip_to_asn => [ qw(ipv4_address) ],
       },
       require_modules => {
-         'Metabrik::File::Fetch' => [ ],
+         'Metabrik::Client::Www' => [ ],
          'Metabrik::File::Read' => [ ],
+         'Metabrik::Network::Address' => [ ],
       },
    };
 }
@@ -41,13 +44,15 @@ sub update {
 
    my @urls = qw(
       ftp://ftp.arin.net/pub/stats/arin/delegated-arin-extended-latest
-      ftp://ftp.ripe.net/ripe/stats/delegated-ripencc-latest
-      ftp://ftp.afrinic.net/pub/stats/afrinic/delegated-afrinic-latest
-      ftp://ftp.apnic.net/pub/stats/apnic/delegated-apnic-latest
-      ftp://ftp.lacnic.net/pub/stats/lacnic/delegated-lacnic-latest
+      ftp://ftp.ripe.net/ripe/stats/delegated-ripencc-extended-latest
+      ftp://ftp.afrinic.net/pub/stats/afrinic/delegated-afrinic-extended-latest
+      ftp://ftp.apnic.net/pub/stats/apnic/delegated-apnic-extended-latest
+      ftp://ftp.lacnic.net/pub/stats/lacnic/delegated-lacnic-extended-latest
    );
 
-   my $file_fetch = Metabrik::File::Fetch->new_from_brik($self) or return;
+   my $datadir = $self->datadir;
+
+   my $cw = Metabrik::Client::Www->new_from_brik_init($self) or return;
 
    my @fetched = ();
    for my $url (@urls) {
@@ -55,12 +60,15 @@ sub update {
 
       (my $filename = $url) =~ s/^.*\/(.*?)$/$1/;
 
-      my $output = $self->datadir.'/'.$filename;
-      my $get = $file_fetch->get($url, $output);
-      if (! defined($get)) {
+      my $output = $datadir.'/'.$filename;
+      my $r = $cw->mirror($url, $filename, $datadir);
+      if (! defined($r)) {
          $self->log->warning("update: can't fetch url [$url]");
          next;
       }
+      if (@$r == 0) { # Nothing new
+         next;
+      }
       push @fetched, $output;
    }
 
@@ -71,30 +79,30 @@ sub next_record {
    my $self = shift;
    my ($input) = @_;
 
-   my $read = $self->_read;
-   if (! defined($read)) {
+   my $fr = $self->_read;
+   if (! defined($fr)) {
       $input ||= $self->datadir.'/'.$self->input;
-      if (! -f $input) {
-         return $self->log->error("next_record: file [$input] does not exist");
-      }
+      $self->brik_help_run_file_not_found('next_record', $input) or return;
 
-      $read = Metabrik::File::Read->new_from_brik($self) or return;
-      $read->encoding('ascii');
-      $read->input($input);
-      $read->as_array(0);
-      $read->open
-         or return $self->log->error("next_record: file::read open failed");
-      $self->_read($read);
+      $fr = Metabrik::File::Read->new_from_brik_init($self) or return;
+      $fr->encoding('ascii');
+      $fr->input($input);
+      $fr->as_array(0);
+      $fr->open or return;
+      $self->_read($fr);
    }
 
+   my $na = Metabrik::Network::Address->new_from_brik_init($self) or return;
+
    # 2|afrinic|20150119|4180|00000000|20150119|00000
    # afrinic|*|asn|*|1146|summary
    # afrinic|*|ipv4|*|2586|summary
    # afrinic|*|ipv6|*|448|summary
    # afrinic|ZA|asn|1228|1|19910301|allocated
+   # arin|US|ipv4|13.128.0.0|524288|19860425|assigned|efe0f73dfd0d72364bf64f417b803f18
 
    my $line;
-   while ($line = $read->read_line) {
+   while ($line = $fr->read_line) {
       next if $line =~ /^\s*#/;  # Skip comments
 
       chomp($line);
@@ -117,31 +125,55 @@ sub next_record {
       }
       next if ($type ne 'asn' && $type ne 'ipv4' && $type ne 'ipv6');
 
-      # XXX: TODO, convert IPv4 to int and add $count, then convert to x-subnet
-
-      my $rir = $t[0];
+      my $source = $t[0];
       my $value = $t[3];
       my $count = $t[4];
       my $date = $t[5];
       my $status = $t[6];
 
-      if ($date !~ /^\d{8}$/) {
-         $self->log->verbose("next_record: invalid date [$date] for line [$line]");
+      if ($date !~ /^\d{8}$/ && $date ne '') {
+         $self->log->warning("next_record: invalid date [$date] for line [$line]");
          $date = '1970-01-01';
       }
       else {
          $date =~ s/^(\d{4})(\d{2})(\d{2})$/$1-$2-$3/;
       }
 
+      my $from = 'undef';
+      my $to = 'undef';
+      my $subnet = 'undef';
+      if ($type eq 'ipv4') {
+         $from = $value;
+         my $integer = $na->ipv4_to_integer($from);
+         if (! defined($integer)) {
+            $self->log->warning("next_record: unable to convert IPv4 [$from]");
+            next;
+         }
+         $to = $na->integer_to_ipv4($integer + $count - 1);
+         if (! defined($to)) {
+            $self->log->warning("next_record: unable to convert integer [".$integer + $count."]");
+            next;
+         }
+         $subnet = $na->range_to_cidr($from, $to);
+         if (! defined($subnet)) {
+            $self->log->warning("next_record: unable to get subnet with [$from] [$to]");
+            next;
+         }
+         $subnet = join('|', @$subnet);
+      }
+
       my $h = {
          raw => $line,
-         rir => $rir,
-         cc => $cc,
+         source => uc($source),
+         cc => uc($cc),
          type => $type,
          value => $value,
          count => $count,
-         'rir-date' => $date,
+         date => $date,
          status => $status,
+         subnet => $subnet,
+         from => $value,
+         to => $to,
       };
 
       return $h;
@@ -167,7 +199,7 @@ Metabrik::Database::Rir - database::rir Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
