@@ -1,5 +1,5 @@
 #
-# $Id: Sinfp3.pm,v 6be0c79591ec 2015/01/07 06:39:25 gomor $
+# $Id: Sinfp3.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # database::sinfp3 Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 6be0c79591ec $',
-      tags => [ qw(unstable network sinfp sinfp3 scanner signature) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable network sinfp scanner signature) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          db => [ qw(sinfp3_db) ],
       },
@@ -35,15 +37,6 @@ sub brik_properties {
    };
 }
 
-sub _brik_use_properties {
-   my $self = shift;
-
-   return {
-      attributes_default => {
-      },
-   };
-}
-
 #
 # sinfp3.pl -input-null -db-sinfp3 -db-file FILE -mode-null -search-null -output Export
 #
@@ -52,13 +45,8 @@ sub active_signature_export {
    my ($file) = @_;
 
    $file ||= $self->db;
-   if (! defined($file)) {
-      return $self->log->error($self->brik_help_set('db'));
-   }
-
-   if (! -f $file) {
-      return $self->log->error("active_signature_export: file [$file] not found");
-   }
+   $self->brik_help_run_undef_arg('active_signature_export', $file) or return;
+   $self->brik_help_run_file_not_found('active_signature_export', $file) or return;
 
    my $log = Net::SinFP3::Log::Console->new(
       level => 0,
@@ -105,13 +93,8 @@ sub passive_signature_export {
    my ($file) = @_;
 
    $file ||= $self->db;
-   if (! defined($file)) {
-      return $self->log->error($self->brik_help_set('db'));
-   }
-
-   if (! -f $file) {
-      return $self->log->error("passive_signature_export: file [$file] not found");
-   }
+   $self->brik_help_run_undef_arg('passive_signature_export', $file) or return;
+   $self->brik_help_run_file_not_found('passive_signature_export', $file) or return;
 
    my $log = Net::SinFP3::Log::Console->new(
       level => 0,
@@ -160,7 +143,7 @@ Metabrik::Database::Sinfp3 - database::sinfp3 Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
