@@ -1,5 +1,5 @@
 #
-# $Id: Sqlite.pm,v 508610fe2b1a 2015/10/27 19:01:31 gomor $
+# $Id: Sqlite.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # database::sqlite Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 508610fe2b1a $',
-      tags => [ qw(unstable database sqlite) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          db => [ qw(sqlite_file) ],
          autocommit => [ qw(0|1) ],
@@ -23,7 +25,7 @@ sub brik_properties {
       },
       commands => {
          open => [ qw(sqlite_file|OPTIONAL) ],
-         exec => [ qw(sql_query) ],
+         execute => [ qw(sql_query) ],
          create => [ qw(table_name fields_array key|OPTIONAL) ],
          insert => [ qw(table_name data_hash) ],
          select => [ qw(table_name fields_array|OPTIONAL key|OPTIONAL) ],
@@ -45,9 +47,7 @@ sub open {
    my ($db) = @_;
 
    $db ||= $self->db;
-   if (! defined($db)) {
-      return $self->log->error($self->brik_help_run('open'));
-   }
+   $self->brik_help_run_undef_arg('open', $db) or return;
 
    my $dbh = DBI->connect('dbi:SQLite:dbname='.$db,'','', {
       AutoCommit => $self->autocommit,
@@ -68,20 +68,15 @@ sub open {
    return 1;
 }
 
-sub exec {
+sub execute {
    my $self = shift;
    my ($sql) = @_;
 
-   if (! defined($sql)) {
-      return $self->log->error($self->brik_help_run('exec'));
-   }
-
    my $dbh = $self->dbh;
-   if (! defined($dbh)) {
-      return $self->log->error($self->brik_help_run('open'));
-   }
+   $self->brik_help_run_undef_arg('open', $dbh) or return;
+   $self->brik_help_run_undef_arg('execute', $sql) or return;
 
-   $self->debug && $self->log->debug("exec: sql[$sql]");
+   $self->debug && $self->log->debug("execute: sql[$sql]");
 
    my $sth = $dbh->prepare($sql);
 
@@ -92,6 +87,7 @@ sub commit {
    my $self = shift;
 
    my $dbh = $self->dbh;
+   $self->brik_help_run_undef_arg('open', $dbh) or return;
 
    if ($self->autocommit) {
       $self->log->verbose("commit: skipping cause autocommit is on");
@@ -113,13 +109,9 @@ sub create {
    my $self = shift;
    my ($table, $fields, $key) = @_;
 
-   if (! defined($table) && ! defined($fields)) {
-      return $self->log->error($self->brik_help_run('create'));
-   }
-
-   if (ref($fields) ne 'ARRAY') {
-      return $self->log->error("create: Argument 'fields' must be ARRAYREF");
-   }
+   $self->brik_help_run_undef_arg('create', $table) or return;
+   $self->brik_help_run_undef_arg('create', $fields) or return;
+   $self->brik_help_run_invalid_arg('create', $fields, 'ARRAY') or return;
 
    # create table TABLE (stuffid INTEGER PRIMARY KEY, field1 VARCHAR(512), field2, date DATE);
    # insert into TABLE (field1) values ("value1");
@@ -139,21 +131,15 @@ sub create {
 
    $self->log->verbose("create: $sql");
 
-   return $self->exec($sql);
+   return $self->execute($sql);
 }
 
 sub insert {
    my $self = shift;
    my ($table, $data) = @_;
 
-   if (! defined($table) && ! defined($data)) {
-      return $self->log->error($self->brik_help_run('insert'));
-   }
-
-   my $dbh = $self->dbh;
-   if (! defined($dbh)) {
-      return $self->log->error($self->brik_help_run('open'));
-   }
+   $self->brik_help_run_undef_arg('insert', $table) or return;
+   $self->brik_help_run_undef_arg('insert', $data) or return;
 
    my @data = ();
    if (ref($data) eq 'ARRAY') {
@@ -187,7 +173,7 @@ sub insert {
 
       $self->log->verbose("insert: $sql");
 
-      $self->exec($sql);
+      $self->execute($sql);
    }
 
    return 1;
@@ -197,24 +183,12 @@ sub select {
    my $self = shift;
    my ($table, $fields, $key) = @_;
 
-   $fields ||= [ '*' ];
-
-   if (! defined($table)) {
-      return $self->log->error($self->brik_help_run('select'));
-   }
-
-   if (ref($fields) ne 'ARRAY') {
-      return $self->log->error("select: Argument 'fields' must be ARRAYREF");
-   }
-
-   if (@$fields == 0) {
-      return $self->log->error("select: Argument 'fields' is empty");
-   }
-
    my $dbh = $self->dbh;
-   if (! defined($dbh)) {
-      return $self->log->error($self->brik_help_run('open'));
-   }
+   $fields ||= [ '*' ];
+   $self->brik_help_run_undef_arg('open', $dbh) or return;
+   $self->brik_help_run_undef_arg('select', $table) or return;
+   $self->brik_help_run_invalid_arg('select', $fields, 'ARRAY') or return;
+   $self->brik_help_run_empty_array_arg('select', $fields) or return;
 
    my $sql = 'SELECT ';
    for (@$fields) {
@@ -239,9 +213,7 @@ sub show_tables {
    my $self = shift;
 
    my $dbh = $self->dbh;
-   if (! defined($dbh)) {
-      return $self->log->error($self->brik_help_run('open'));
-   }
+   $self->brik_help_run_undef_arg('open', $dbh) or return;
 
    # $dbh->table_info(undef, $schema, $table, $type, \%attr);
    # $type := 'TABLE', 'VIEW', 'LOCAL TEMPORARY' and 'SYSTEM TABLE'
@@ -295,7 +267,7 @@ Metabrik::Database::Sqlite - database::sqlite Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
