@@ -1,5 +1,5 @@
 #
-# $Id: Send.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Send.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # email::send Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik::Network::Smtp);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
-      tags => [ qw(unstable email send smtp) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable smtp) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          from => [ qw(from) ],
          to => [ qw(to) ],
@@ -24,7 +26,7 @@ sub brik_properties {
          subject => 'My subject',
       },
       commands => {
-         send => [ qw(email) ],
+         send => [ qw(email from|OPTIONAL to|OPTIONAL subject|OPTIONAL) ],
       },
       require_modules => {
          'DateTime' => [ ],
@@ -35,28 +37,16 @@ sub brik_properties {
 
 sub send {
    my $self = shift;
-   my ($email) = @_;
+   my ($email, $from, $to, $subject) = @_;
 
-   my $smtp = $self->open or return $self->log->error("send: open failed");
-
-   my $from = $self->from;
-   if (! defined($from)) {
-      return $self->log->error($self->brik_help_set('from'));
-   }
-
-   my $to = $self->to;
-   if (! defined($to)) {
-      return $self->log->error($self->brik_help_set('to'));
-   }
-
-   my $subject = $self->subject;
-   if (! defined($subject)) {
-      return $self->log->error($self->brik_help_set('subject'));
-   }
-
-   if (ref($email) ne 'Email::Simple') {
-      return $self->log->error("send: can only send Email::Simple objects");
-   }
+   $from ||= $self->from;
+   $to ||= $self->to;
+   $subject ||= $self->subject;
+   $self->brik_help_run_undef_arg('send', $email) or return;
+   $self->brik_help_run_invalid_arg('send', $email, 'Email::Simple') or return;
+   $self->brik_help_run_undef_arg('send', $from) or return;
+   $self->brik_help_run_undef_arg('send', $to) or return;
+   $self->brik_help_run_undef_arg('send', $subject) or return;
 
    my $ct = $email->header('Content-Type');
    my $cl = $email->header('Content-Length');
@@ -73,6 +63,8 @@ sub send {
    #print "Content-Type [$ct]\n\n";
    #print $email->body,"\n";
 
+   my $smtp = $self->open or return;
+
    $smtp->mail($from);
    $smtp->to($to);
 
@@ -105,7 +97,7 @@ Metabrik::Email::Send - email::send Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
