@@ -1,5 +1,5 @@
 #
-# $Id: Dump.pm,v 887d85a7f604 2015/11/12 14:44:58 gomor $
+# $Id: Dump.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # file::dump Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik::File::Write);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 887d85a7f604 $',
-      tags => [ qw(unstable file dump read write) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable read write) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          input => [ qw(file) ],
          output => [ qw(file) ],
@@ -26,8 +28,8 @@ sub brik_properties {
          write => [ qw($data|$data_ref|$data_list output|OPTIONAL) ],
       },
       require_modules => {
-         'Metabrik::File::Read' => [ ],
          'Data::Dump' => [ ],
+         'Metabrik::File::Read' => [ ],
       },
    };
 }
@@ -37,9 +39,7 @@ sub read {
    my ($input) = @_;
 
    $input ||= $self->input;
-   if (! defined($input)) {
-      return $self->log->error($self->brik_help_run('read'));
-   }
+   $self->brik_help_run_undef_arg('read', $input) or return;
 
    my $fr = Metabrik::File::Read->new_from_brik_init($self) or return;
    $fr->input($input);
@@ -47,8 +47,8 @@ sub read {
    $fr->as_array(1);
    $fr->strip_crlf(1);
 
-   $fr->open or return $self->log->error("read: open failed");
-   my $data = $fr->read or return $self->log->error("read: read failed");
+   $fr->open or return;
+   my $data = $fr->read or return;
    $fr->close;
 
    my @vars = ();
@@ -62,6 +62,12 @@ sub read {
       }
    }
 
+   # Gather last remaining line, if any
+   if (length($buf)) {
+      push @vars, $buf;
+      $buf = '';
+   }
+
    my @res = ();
    for (@vars) {
       my $h = eval($_);
@@ -80,18 +86,13 @@ sub write {
    my $self = shift;
    my ($data, $output) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('write'));
-   }
-
    $output ||= $self->output;
-   if (! defined($output)) {
-      return $self->log->error($self->brik_help_run('write'));
-   }
+   $self->brik_help_run_undef_arg('write', $data) or return;
+   $self->brik_help_run_undef_arg('write', $output) or return;
 
    $self->debug && $self->log->debug("write: data[$data]");
 
-   $self->open($output) or return $self->log->error("write: open failed");
+   $self->open($output) or return;
 
    if (ref($data) eq 'ARRAY') {
       for (@$data) {
@@ -123,7 +124,7 @@ Metabrik::File::Dump - file::dump Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
