@@ -1,5 +1,5 @@
 #
-# $Id: Ole.pm,v 75fc1a5bf385 2016/09/28 05:57:21 gomor $
+# $Id: Ole.pm,v fc658e60fb76 2016/10/08 15:24:49 gomor $
 #
 # file::ole Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Shell::Command Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 75fc1a5bf385 $',
+      revision => '$Revision: fc658e60fb76 $',
       tags => [ qw(unstable read vbs) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -36,7 +36,8 @@ sub brik_properties {
          'python' => [ ],
       },
       need_packages => {
-         'ubuntu' => [ qw(python python-pip) ],
+         ubuntu => [ qw(python python-pip) ],
+         debian => [ qw(python python-pip) ],
       },
    };
 }
