@@ -1,5 +1,5 @@
 #
-# $Id: Psv.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Psv.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # file::psv Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik::File::Csv);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
-      tags => [ qw(unstable psv file) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes_default => {
          separator => "|",
       },
@@ -29,7 +31,7 @@ Metabrik::File::Psv - file::psv Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
