@@ -1,5 +1,5 @@
 #
-# $Id: Write.pm,v 5be2a244bacc 2015/03/26 07:06:31 gomor $
+# $Id: Write.pm,v 6681de14037f 2016/01/16 16:06:27 gomor $
 #
 # file::write Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 5be2a244bacc $',
-      tags => [ qw(unstable file) ],
+      revision => '$Revision: 6681de14037f $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          output => [ qw(file) ],
          append => [ qw(0|1) ],
@@ -27,8 +29,8 @@ sub brik_properties {
          unbuffered => 0,
       },
       commands => {
-         open => [ qw(file|OPTIONAL RETURN:$fd) ],
-         write => [ qw($data|$data_ref|$data_list RETURN:$data|$data_ref|$data_list) ],
+         open => [ qw(file|OPTIONAL) ],
+         write => [ qw($data|$data_ref|$data_list) ],
          close => [ ],
       },
    };
@@ -40,7 +42,6 @@ sub brik_use_properties {
    # encoding: see `perldoc Encode::Supported' for other types
    return {
       attributes_default => {
-         output => $self->global->output || '/tmp/output.txt',
          encoding => $self->global->encoding || 'utf8',
       },
    };
@@ -51,9 +52,7 @@ sub open {
    my ($output) = @_;
 
    $output ||= $self->output;
-   if (! defined($output)) {
-      return $self->log->error($self->brik_help_set('output'));
-   }
+   $self->brik_help_run_undef_arg('open', $output) or return;
 
    my $encoding = $self->encoding;
    if ($encoding eq 'ascii') {
@@ -73,7 +72,7 @@ sub open {
          return $self->log->error("open: open: write file [$output]: $!");
       }
    }
-   elsif (! $self->append && ! $self->overwrite && -f $self->output) {
+   elsif (! $self->append && ! $self->overwrite && -f $output) {
       $self->log->info("open: we will not overwrite an existing file. See:");
       return $self->log->error($self->brik_help_set('overwrite'));
    }
@@ -105,17 +104,12 @@ sub write {
    my $self = shift;
    my ($data) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('write'));
-   }
+   my $fd = $self->fd;
+   $self->brik_help_run_undef_arg('open', $fd) or return;
+   $self->brik_help_run_undef_arg('write', $data) or return;
 
    $self->debug && $self->log->debug("write: data[$data]");
 
-   my $fd = $self->fd;
-   if (! defined($fd)) {
-      return $self->log->error($self->brik_help_run('open'));
-   }
-
    if (ref($data) eq 'ARRAY') {
       for my $this (@$data) {
          print $fd $this."\n";
@@ -138,7 +132,7 @@ Metabrik::File::Write - file::write Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
