@@ -1,5 +1,5 @@
 #
-# $Id: Volatility.pm,v 249e2a3ccbd7 2016/01/09 14:52:23 gomor $
+# $Id: Volatility.pm,v fc658e60fb76 2016/10/08 15:24:49 gomor $
 #
 # forensic::Volatility Brik
 #
@@ -12,7 +12,7 @@ use base qw(Metabrik::Shell::Command Metabrik::System::Package);
 # Default attribute values put here will BE inherited by subclasses
 sub brik_properties {
    return {
-      revision => '$Revision: 249e2a3ccbd7 $',
+      revision => '$Revision: fc658e60fb76 $',
       tags => [ qw(unstable carving carve file filecarve filecarving) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -49,7 +49,8 @@ sub brik_properties {
          'volatility' => [ ],
       },
       need_packages => {
-         'ubuntu' => [ qw(volatility) ],
+         ubuntu => [ qw(volatility) ],
+         debian => [ qw(volatility) ],
       },
    };
 }
