@@ -1,5 +1,5 @@
 #
-# $Id: Battery.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Battery.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # harware::battery Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik::File::Text);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
-      tags => [ qw(unstable hardware battery) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       commands => {
          capacity => [ ],
       },
@@ -23,6 +25,7 @@ sub capacity {
    my $self = shift;
 
    my $base_file = '/sys/class/power_supply/BAT';
+   $self->brik_help_run_file_not_found('capacity', $base_file) or return;
 
    my $battery_hash = {};
    my $count = 0;
@@ -52,7 +55,7 @@ Metabrik::Hardware::Battery - hardware::battery Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
