@@ -1,5 +1,5 @@
 #
-# $Id: Temperature.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Temperature.pm,v c11497d88a72 2015/12/28 18:20:13 gomor $
 #
 # hardware::temperature Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik::File::Text);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
-      tags => [ qw(unstable hardware temperature) ],
+      revision => '$Revision: c11497d88a72 $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       commands => {
          cpu => [ ],
       },
@@ -23,12 +25,9 @@ sub cpu {
    my $self = shift;
 
    my $file = "/sys/class/thermal/thermal_zone0/temp";
-   if (! -f $file) {
-      return $self->log->error("cpu: can't find file [$file]");
-   }
+   $self->brik_help_run_file_not_found('cpu', $file) or return;
 
-   my $text = $self->read($file)
-      or return $self->log->error("cpu: can't read file [$file]");
+   my $text = $self->read($file) or return;
 
    if (length($text)) {
       chomp($text);
