@@ -1,5 +1,5 @@
 #
-# $Id: Convert.pm,v b85f09c7ad39 2016/01/09 19:35:59 gomor $
+# $Id: Convert.pm,v fc658e60fb76 2016/10/08 15:24:49 gomor $
 #
 # image::convert Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Shell::Command Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: b85f09c7ad39 $',
+      revision => '$Revision: fc658e60fb76 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -30,7 +30,8 @@ sub brik_properties {
          'convert' => [ ],
       },
       need_packages => {
-         'ubuntu' => [ qw(imagemagick) ],
+         ubuntu => [ qw(imagemagick) ],
+         debian => [ qw(imagemagick) ],
       },
    };
 }
