@@ -1,5 +1,5 @@
 #
-# $Id: Null.pm,v 3a618b2c89fc 2016/02/01 06:36:57 gomor $
+# $Id: Null.pm,v b854c1d9459a 2016/04/11 17:14:14 gomor $
 #
 # log::null Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Core::Log);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 3a618b2c89fc $',
+      revision => '$Revision: b854c1d9459a $',
       tags => [ qw(unstable logging) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -19,6 +19,7 @@ sub brik_properties {
          level => [ qw(0|1|2|3) ],
       },
       commands => {
+         message => [ qw(string caller|OPTIONAL) ],
          info => [ qw(string caller|OPTIONAL) ],
          verbose => [ qw(string caller|OPTIONAL) ],
          warning => [ qw(string caller|OPTIONAL) ],
@@ -29,17 +30,6 @@ sub brik_properties {
    };
 }
 
-sub _msg {
-   my $self = shift;
-   my ($brik, $msg) = @_;
-
-   $msg ||= 'undef';
-
-   $brik =~ s/^metabrik:://i;
-
-   return lc($brik).": $msg\n";
-}
-
 sub warning {
    my $self = shift;
 
@@ -56,7 +46,7 @@ sub fatal {
    my $self = shift;
    my ($msg, $caller) = @_;
 
-   my $buffer = "[F] ".$self->_msg(($caller) ||= caller(), $msg);
+   my $buffer = "[F] ".$self->message($msg, ($caller) ||= caller());
 
    die($buffer);
 }
