@@ -1,5 +1,5 @@
 #
-# $Id: Syslog.pm,v b854c1d9459a 2016/04/11 17:14:14 gomor $
+# $Id: Syslog.pm,v b5a7d96de9f1 2016/10/11 06:17:23 gomor $
 #
 # log::syslog Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Core::Log);
 
 sub brik_properties {
    return {
-      revision => '$Revision: b854c1d9459a $',
+      revision => '$Revision: b5a7d96de9f1 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -23,6 +23,7 @@ sub brik_properties {
          text_prefix => [ qw(0|1) ],
          facility => [ qw(kernel|user|mail|system|security|internal|printer|news|uucp|clock|security2|FTP|NTP|audit|alert|clock2|local0|local1|local2|local3|local4|local5|local6|local7) ],
          name => [ qw(program) ],
+         do_rfc3164 => [ qw(0|1) ],
          _fd => [ qw(INTERNAL) ],
       },
       attributes_default => {
@@ -33,6 +34,7 @@ sub brik_properties {
          port => 514,
          facility => 'local5',
          name => 'metabrik',
+         do_rfc3164 => 0,
       },
       commands => {
          send => [ qw(message priority) ],
@@ -86,6 +88,7 @@ sub send {
    my $port = $self->port;
    my $name = $self->name;
    my $facility = $self->facility;
+   my $rfc3164 = $self->do_rfc3164;
 
    # Priorities can be:
    # emergency, alert, critical, error, warning, notice, informational, debug
@@ -97,6 +100,7 @@ sub send {
       Priority => $priority,
       SyslogHost => $host,
       SyslogPort => $port,
+      rfc3164 => $rfc3164,
    );
    if (! defined($r)) {
       return $self->log->error("send: unable to send message to [$host]:$port");
