@@ -1,5 +1,5 @@
 #
-# $Id: Alexa.pm,v 6391b00ed43b 2016/01/26 20:00:14 gomor $
+# $Id: Alexa.pm,v fe6cf91cad64 2016/06/05 08:56:48 gomor $
 #
 # lookup::alexa Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Client::Www);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 6391b00ed43b $',
+      revision => '$Revision: fe6cf91cad64 $',
       tags => [ qw(unstable top million 1m) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -29,6 +29,8 @@ sub brik_properties {
          update => [ ],
          load => [ qw(input|OPTIONAL) ],
          from_string => [ qw(domain) ],
+         from_pattern => [ qw(domain) ],
+         list_from_pattern => [ qw(domain) ],
       },
       require_modules => {
          'Metabrik::File::Compress' => [ ],
@@ -97,6 +99,49 @@ sub from_string {
    return 0;
 }
 
+sub from_pattern {
+   my $self = shift;
+   my ($domain) = @_;
+
+   $self->brik_help_run_undef_arg('from_pattern', $domain) or return;
+
+   my $data = $self->_loaded;
+   if (! defined($data)) {
+      $data = $self->load or return;
+      $self->_loaded($data);
+   }
+
+   for my $this (@$data) {
+      if ($this->[1] =~ m{$domain}i) {
+         return 1;
+      }
+   }
+
+   return 0;
+}
+
+sub list_from_pattern {
+   my $self = shift;
+   my ($domain) = @_;
+
+   $self->brik_help_run_undef_arg('list_from_pattern', $domain) or return;
+
+   my $data = $self->_loaded;
+   if (! defined($data)) {
+      $data = $self->load or return;
+      $self->_loaded($data);
+   }
+
+   my @list = ();
+   for my $this (@$data) {
+      if ($this->[1] =~ m{$domain}i) {
+         push @list, $this->[1];
+      }
+   }
+
+   return \@list;
+}
+
 1;
 
 __END__
