@@ -1,5 +1,5 @@
 #
-# $Id: Countrycode.pm,v 35a2fef2b5f8 2016/01/19 13:11:10 gomor $
+# $Id: Countrycode.pm,v be8fd29d6b2b 2016/03/21 19:51:52 gomor $
 #
 # lookup::countrycode Brik
 #
@@ -11,39 +11,75 @@ use base qw(Metabrik::Client::Www);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 35a2fef2b5f8 $',
-      tags => [ qw(unstable iana cc) ],
+      revision => '$Revision: be8fd29d6b2b $',
+      tags => [ qw(unstable iana cc tld) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          datadir => [ qw(datadir) ],
          input => [ qw(file) ],
-         output => [ qw(file) ],
-      },
-      attributes_default => {
-         input => 'country-codes.csv',
-         output => 'country-codes.csv',
+         _data => [ qw(INTERNAL) ],
+         _data_by_tld => [ qw(INTERNAL) ],
       },
       commands => {
          update => [ ],
          load => [ qw(input|OPTIONAL) ],
-         country_code_types => [ qw($csv_struct) ],
+         load_by_tld => [ qw(input|OPTIONAL) ],
+         list_types => [ ],
+         list_tlds => [ ],
+         from_tld => [ qw(tld) ],
       },
       require_modules => {
          'Metabrik::File::Csv' => [ ],
+         'Metabrik::System::File' => [ ],
       },
    };
 }
 
-sub country_code_types {
+sub brik_use_properties {
    my $self = shift;
-   my ($data) = @_;
 
-   $self->brik_help_run_undef_arg('country_code_types', $data) or return;
+   my $datadir = $self->datadir;
+
+   return {
+      attributes_default => {
+         input => $datadir.'/country-codes.csv',
+      },
+   };
+}
+
+sub _load {
+   my $self = shift;
+
+   my $data = $self->_data;
+   if (! defined($data)) {
+      $data = $self->load or return;
+      $self->_data($data);
+   }
+
+   return $data;
+}
+
+sub _load_by_tld {
+   my $self = shift;
+
+   my $data = $self->_data_by_tld;
+   if (! defined($data)) {
+      $data = $self->load_by_tld or return;
+      $self->_data_by_tld($data);
+   }
+
+   return $data;
+}
+
+sub list_types {
+   my $self = shift;
+
+   my $data = $self->_load or return;
 
    my %list = ();
    for my $this (@$data) {
-      $list{$data->{$this}->{type}}++;
+      $list{$this->{type}}++;
    }
 
    my @types = sort { $a cmp $b } keys %list;
@@ -51,6 +87,21 @@ sub country_code_types {
    return \@types;
 }
 
+sub list_tlds {
+   my $self = shift;
+
+   my $data = $self->_load or return;
+
+   my %list = ();
+   for my $this (@$data) {
+      $list{$this->{tld}}++;
+   }
+
+   my @tlds = sort { $a cmp $b } keys %list;
+
+   return \@tlds;
+}
+
 #
 # Port numbers:
 # http://www.iana.org/protocols
@@ -58,25 +109,17 @@ sub country_code_types {
 #
 sub update {
    my $self = shift;
-   my ($output) = @_;
 
-   $output ||= $self->output;
-   $self->brik_help_run_undef_arg('update', $output) or return;
+   my $input = $self->input;
 
-   my $datadir = $self->datadir;
+   my $sf = Metabrik::System::File->new_from_brik_init($self) or return;
+   $sf->remove($input);
 
    my $uri = 'http://www.iana.org/domains/root/db';
 
    my $get = $self->get($uri) or return;
    my $html = $get->{content};
 
-   # <tr class="iana-group-1 iana-type-2">
-   #   <td><span class="domain tld"><a href="/domains/root/db/abogado.html">.abogado</a></span></td>
-   #   <td>generic</td>
-   #   <!-- <td>-<br/><span class="tld-table-so">Top Level Domain Holdings Limited</span></td> </td> -->
-   #   <td>Top Level Domain Holdings Limited</td>
-   # </tr>
-
    my @cc = ();
    while ($html =~ m{<span class="domain tld">(.*?)</tr>}gcs) {
       my $this = $1;
@@ -85,13 +128,24 @@ sub update {
 
       $self->debug && $self->log->debug("update: this[$this]");
 
-      my ($tld, $type, $country, $sponsor) = ($this =~ m{^.*?<a href.*?>(.*?)<.*?<td>(.*?)<.*?<td>(.*?)<.*$});
+      # <tr>
+      #  <td>
+      #   <span class="domain tld"><a href="/domains/root/db/aaa.html">.aaa</a></span></td>
+      #  <td>generic</td>
+      #  <td>American Automobile Association, Inc.</td>
+      # </tr>
+
+      my ($tld, $type, $sponsor) =
+         ($this =~ m{^.*?<a href.*?>(.*?)<.*?<td>(.*?)<.*?<td>(.*?)<.*$});
+
+      # Remove leading . and put to lowercase
+      $tld =~ s{^\.}{};
+      $tld = lc($tld);
 
       push @cc, {
          tld => $tld,
-         country => $country,
-         type => $type,
-         sponsor => $sponsor,
+         type => "\"$type\"",
+         sponsor => "\"$sponsor\"",
       };
    }
 
@@ -99,11 +153,13 @@ sub update {
    $fc->append(0);
    $fc->overwrite(1);
    $fc->encoding('utf8');
+   $fc->write_header(1);
+   $fc->separator(',');
+   $fc->header([qw(tld type sponsor)]);
 
-   my $output_file = $datadir.'/'.$output;
-   $fc->write(\@cc, $output_file) or return;
+   $fc->write(\@cc, $input) or return;
 
-   return $output_file;
+   return $input;
 }
 
 sub load {
@@ -114,16 +170,54 @@ sub load {
    $self->brik_help_run_undef_arg('load', $input) or return;
    $self->brik_help_run_file_not_found('load', $input) or return;
 
-   my $datadir = $self->datadir;
-
    my $fc = Metabrik::File::Csv->new_from_brik_init($self) or return;
+   $fc->encoding('utf8');
    $fc->first_line_is_header(1);
+   $fc->separator(',');
 
-   my $csv = $fc->read($datadir.'/'.$input) or return;
+   my $csv = $fc->read($input) or return;
 
    return $csv;
 }
 
+sub load_by_tld {
+   my $self = shift;
+   my ($input) = @_;
+
+   $input ||= $self->input;
+   $self->brik_help_run_undef_arg('load_by_tld', $input) or return;
+   $self->brik_help_run_file_not_found('load_by_tld', $input) or return;
+
+   my $fc = Metabrik::File::Csv->new_from_brik_init($self) or return;
+   $fc->encoding('utf8');
+   $fc->first_line_is_header(1);
+   $fc->separator(',');
+
+   my $csv = $fc->read($input) or return;
+
+   my %by_tld = ();
+   for (@$csv) {
+      $by_tld{$_->{tld}} = $_;
+   }
+
+   return \%by_tld;
+}
+
+sub from_tld {
+   my $self = shift;
+   my ($tld) = @_;
+
+   $self->brik_help_run_undef_arg('from_tld', $tld) or return;
+
+   my $data = $self->_load_by_tld or return;
+
+   if (exists($data->{$tld})) {
+      return $data->{$tld};
+   }
+
+   return 0;
+}
+
 1;
 
 __END__
@@ -135,7 +229,6 @@ Metabrik::Lookup::Countrycode - lookup::countrycode Brik
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
-
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
 
