@@ -1,5 +1,5 @@
 #
-# $Id: Ip.pm,v e9efd64d88ce 2015/02/26 06:10:35 gomor $
+# $Id: Ip.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # lookup::ip Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik::Lookup::Ethernet);
 
 sub brik_properties {
    return {
-      revision => '$Revision: e9efd64d88ce $',
-      tags => [ qw(unstable lookup ipv4 ipv6 ip) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable ipv4 ipv6) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       commands => {
          from_dec => [ qw(dec_number) ],
          from_hex => [ qw(hex_number) ],
@@ -94,7 +96,7 @@ Metabrik::Lookup::Ip - lookup::ip Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
