@@ -1,5 +1,5 @@
 #
-# $Id: Iplocation.pm,v 79726574f5ff 2015/11/12 08:51:19 gomor $
+# $Id: Iplocation.pm,v 811ac7ccde81 2016/02/22 18:15:08 gomor $
 #
 # lookup::iplocation Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 79726574f5ff $',
-      tags => [ qw(unstable lookup location ipv4 ipv6 ip geo geolocation iplocation) ],
+      revision => '$Revision: 811ac7ccde81 $',
+      tags => [ qw(unstable location ipv4 ipv6 ip geo geolocation) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          datadir => [ qw(datadir) ],
       },
@@ -28,6 +30,7 @@ sub brik_properties {
          'Geo::IP' => [ ],
          'Metabrik::Client::Www' => [ ],
          'Metabrik::File::Compress' => [ ],
+         'Metabrik::Network::Address' => [ ],
       },
    };
 }
@@ -53,25 +56,25 @@ sub update {
    my $fc = Metabrik::File::Compress->new_from_brik_init($self) or return;
    $fc->datadir($datadir);
 
+   my @updated = ();
    for my $f (keys %mirror) {
       my $files = $cw->mirror($dl_path.$mirror{$f}, $f) or next;
       for my $file (@$files) {
          (my $outfile = $file) =~ s/\.gz$//;
          $self->log->verbose("update: uncompressing to [$outfile]");
-         $fc->uncompress($datadir.'/'.$file, $outfile) or next;
+         $fc->uncompress($file, $outfile) or next;
+         push @updated, $outfile;
       }
    }
 
-   return 1;
+   return \@updated;
 }
 
 sub from_ipv4 {
    my $self = shift;
    my ($ipv4) = @_;
 
-   if (! defined($ipv4)) {
-      return $self->log->error($self->brik_help_run('from_ipv4'));
-   }
+   $self->brik_help_run_undef_arg('from_ipv4', $ipv4) or return;
 
    my $gi = Geo::IP->open($self->datadir.'/GeoIPCity.dat', Geo::IP::GEOIP_STANDARD())
       or return $self->log->error("from_ipv4: unable to open GeoIPCity.dat");
@@ -86,9 +89,7 @@ sub from_ipv6 {
    my $self = shift;
    my ($ipv6) = @_;
 
-   if (! defined($ipv6)) {
-      return $self->log->error($self->brik_help_run('from_ipv6'));
-   }
+   $self->brik_help_run_undef_arg('from_ipv6', $ipv6) or return;
 
    my $gi = Geo::IP->open($self->datadir.'/GeoIPv6.dat')
       or return $self->log->error("from_ipv6: unable to open GeoIPv6.dat");
@@ -103,9 +104,7 @@ sub from_ip {
    my $self = shift;
    my ($ip) = @_;
 
-   if (! defined($ip)) {
-      return $self->log->error($self->brik_help_run('from_ip'));
-   }
+   $self->brik_help_run_undef_arg('from_ip', $ip) or return;
 
    my $na = Metabrik::Network::Address->new_from_brik_init($self) or return;
    if ($na->is_ipv4($ip)) {
@@ -124,9 +123,7 @@ sub subnet4 {
    my $self = shift;
    my ($ipv4_address) = @_;
 
-   if (! defined($ipv4_address)) {
-      return $self->log->error($self->brik_help_run('subnet4'));
-   }
+   $self->brik_help_run_undef_arg('subnet4', $ipv4_address) or return;
 
    my $gi = Geo::IP->open($self->datadir.'/GeoIPCity.dat', Geo::IP::GEOIP_STANDARD())
       or return $self->log->error("subnet4: unable to open GeoIPCity.dat");
@@ -140,9 +137,7 @@ sub organization_name {
    my $self = shift;
    my ($ip_address) = @_;
 
-   if (! defined($ip_address)) {
-      return $self->log->error($self->brik_help_run('organization_name'));
-   }
+   $self->brik_help_run_undef_arg('organization_name', $ip_address) or return;
   
    my $gi = Geo::IP->open($self->datadir.'/GeoIPCity.dat', Geo::IP::GEOIP_STANDARD())
       or return $self->log->error("organization_name: unable to open GeoIPCity.dat");
@@ -162,7 +157,7 @@ Metabrik::Lookup::Iplocation - lookup::iplocation Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
