@@ -1,5 +1,5 @@
 #
-# $Id: Tcpoption.pm,v 0f9363bc68e9 2015/02/26 06:06:26 gomor $
+# $Id: Tcpoption.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # lookup::tcpoption Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik::File::Csv);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 0f9363bc68e9 $',
-      tags => [ qw(unstable lookup tcp tcpoption option iana) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable tcp option iana) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          datadir => [ qw(datadir) ],
          input => [ qw(input) ],
@@ -30,7 +32,7 @@ sub brik_properties {
          from_string => [ qw(protocol_string) ],
       },
       require_modules => {
-         'Metabrik::File::Fetch' => [ ],
+         'Metabrik::Client::Www' => [ ],
          'Metabrik::File::Text' => [ ],
       },
    };
@@ -43,11 +45,14 @@ sub update {
    my $url = 'http://www.iana.org/assignments/tcp-parameters/tcp-parameters-1.csv';
    my ($file) = $self->input;
 
-   $output ||= $self->datadir.'/'.$file;
+   my $datadir = $self->datadir;
+   $output ||= $datadir.'/'.$file;
 
-   my $ff = Metabrik::File::Fetch->new_from_brik_init($self) or return;
-   $ff->get($url, $output)
-      or return $self->log->error("update: get failed");
+   my $cw = Metabrik::Client::Www->new_from_brik_init($self) or return;
+   my $files = $cw->mirror($url, $file, $datadir) or return;
+   if (@$files == 0) {  # Nothing new
+      return $output;
+   }
 
    # We have to rewrite the CSV file, cause some entries are multiline.
    my $ft = Metabrik::File::Text->new_from_brik_init($self) or return;
@@ -73,12 +78,9 @@ sub load {
    my ($input) = @_;
 
    $input ||= $self->datadir.'/'.$self->input;
-   if (! -f $input) {
-      return $self->log->error("load: file [$input] not found");
-   }
+   $self->brik_help_run_file_not_found('load', $input) or return;
 
-   my $data = $self->read($input)
-      or return $self->log->error("load: read failed");
+   my $data = $self->read($input) or return;
 
    return $self->_load($data);
 }
@@ -87,9 +89,7 @@ sub from_dec {
    my $self = shift;
    my ($dec) = @_;
 
-   if (! defined($dec)) {
-      return $self->log->error($self->brik_help_run('from_dec'));
-   }
+   $self->brik_help_run_undef_arg('from_dec', $dec) or return;
 
    my $data = $self->_load || $self->load;
    if (! defined($data)) {
@@ -103,16 +103,14 @@ sub from_dec {
    }
 
    # No match
-   return 'unknown';
+   return 'undef';
 }
 
 sub from_hex {
    my $self = shift;
    my ($hex) = @_;
 
-   if (! defined($hex)) {
-      return $self->log->error($self->brik_help_run('from_hex'));
-   }
+   $self->brik_help_run_undef_arg('from_hex', $hex) or return;
 
    my $dec = hex($hex);
 
@@ -123,9 +121,7 @@ sub from_string {
    my $self = shift;
    my ($string) = @_;
 
-   if (! defined($string)) {
-      return $self->log->error($self->brik_help_run('from_string'));
-   }
+   $self->brik_help_run_undef_arg('from_string', $string) or return;
 
    my $data = $self->_load || $self->load;
    if (! defined($data)) {
@@ -155,7 +151,7 @@ Metabrik::Lookup::Tcpoption - lookup::tcpoption Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
