@@ -1,5 +1,5 @@
 #
-# $Id: Icmp.pm,v 1cb13feea4e0 2015/03/08 11:51:58 gomor $
+# $Id: Icmp.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # network::icmp Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik::Network::Frame);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cb13feea4e0 $',
-      tags => [ qw(unstable icmp ping redirect doubleredirect mitm) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable ping redirect doubleredirect mitm) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       commands => {
          ping => [ qw(ipv4_address) ],
          half_poison => [ ],
@@ -29,7 +31,7 @@ sub brik_use_properties {
 
    return {
       attributes_default => {
-         device => $self->global->device || 'eth0',
+         device => $self->global->device,
       },
    };
 }
@@ -38,9 +40,7 @@ sub ping {
    my $self = shift;
    my ($target) = @_;
 
-   if (! defined($target)) {
-      return $self->log->error($self->brik_help_run('ping'));
-   }
+   $self->brik_help_run_undef_arg('ping', $target) or return;
 
    my $ipv4 = $self->ipv4;
    $ipv4->dst($target);
@@ -59,11 +59,11 @@ sub ping {
    my $frame2 = $self->frame([ $ipv4, $icmpv4, $echo2 ]);
    my $frame3 = $self->frame([ $ipv4, $icmpv4, $echo3 ]);
 
-   my $write = Metabrik::Network::Write->new_from_brik($self) or return;
+   my $nw = Metabrik::Network::Write->new_from_brik_init($self) or return;
 
    # We must use different Net::Frame::Simple objects so recv() method will work
    for my $f ($frame1, $frame2, $frame3) {
-      my $r = $write->fnsend_reply($f)
+      my $r = $nw->fnsend_reply($f)
          or return $self->log->error("ping: network::write fnsend_reply failed");
       if (defined($r)) {
          print $r->print."\n";
@@ -100,7 +100,7 @@ Metabrik::Network::Icmp - network::icmp Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
