@@ -1,5 +1,5 @@
 #
-# $Id: Modbus.pm,v 508610fe2b1a 2015/10/27 19:01:31 gomor $
+# $Id: Modbus.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # network::modbus Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik::Client::Tcp);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 508610fe2b1a $',
-      tags => [ qw(unstable modbus) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       commands => {
          probe => [ qw(host port|OPTIONAL) ],
       },
@@ -25,10 +27,7 @@ sub probe {
 
    $host ||= $self->host;
    $port ||= 502;
-
-   if (! defined($host)) {
-      return $self->log->error($self->brik_help_run('probe'));
-   }
+   $self->brik_help_run_undef_arg('probe', $host) or return;
 
    # XXX: gather nmap --script modbus-discovery -p 502 <IP>
 
@@ -39,9 +38,9 @@ sub probe {
 
    $self->host($host);
    $self->port($port);
-   $self->connect or return $self->log->error("probe: connect failed");
-   $self->write($probe) or return $self->log->error("probe: write failed");
-   my $response = $self->read or return $self->log->error("probe: read failed");
+   $self->connect or return;
+   $self->write($probe) or return;
+   my $response = $self->read or return;
    $self->disconnect;
 
    return $response;
@@ -57,7 +56,7 @@ Metabrik::Network::Modbus - network::modbus Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
