@@ -1,5 +1,5 @@
 #
-# $Id: Netstat.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
+# $Id: Netstat.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # network::netstat Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik::Shell::Command);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1db92d72d9a2 $',
-      tags => [ qw(unstable netstat listen) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable listen) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       commands => {
          udp_listen => [ ],
          tcp_listen => [ ],
@@ -79,7 +81,7 @@ Metabrik::Network::Netstat - network::netstat Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
