@@ -1,5 +1,5 @@
 #
-# $Id: Nikto.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Nikto.pm,v fc658e60fb76 2016/10/08 15:24:49 gomor $
 #
 # network::nikto Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
+      revision => '$Revision: fc658e60fb76 $',
       tags => [ qw(unstable security scanner vulnerability vuln scan) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -37,7 +37,8 @@ sub brik_properties {
          'nikto' => [ ],
       },
       need_packages => {
-         'ubuntu' => [ qw(nikto) ],
+         ubuntu => [ qw(nikto) ],
+         debian => [ qw(nikto) ],
       },
    };
 }
