@@ -1,5 +1,5 @@
 #
-# $Id: Route.pm,v 714d5f4c8eff 2015/11/22 11:38:52 gomor $
+# $Id: Route.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # network::route Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 714d5f4c8eff $',
-      tags => [ qw(unstable route) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          device => [ qw(device) ],
       },
@@ -50,7 +52,7 @@ sub brik_use_properties {
 sub show {
    my $self = shift;
 
-   $self->log->info("show: IPv4 network routes:");
+   print "show: IPv4 network routes:\n";
 
    my $nr4 = Net::Routing->new(
       target => Net::Routing::NR_TARGET_ALL(),
@@ -60,7 +62,7 @@ sub show {
 
    print "\n";
 
-   $self->log->info("show: IPv6 network routes:");
+   print "show: IPv6 network routes:\n";
 
    my $nr6 = Net::Routing->new(
       target => Net::Routing::NR_TARGET_ALL(),
@@ -158,17 +160,15 @@ sub is_router_ipv4 {
    my ($device) = @_;
 
    $device ||= $self->device;
-   if (! defined($device)) {
-      return $self->log->error($self->brik_help_run('is_router_ipv4'));
-   }
+   $self->brik_help_run_undef_arg('is_router_ipv4', $device) or return;
 
-   my $command = Metabrik::Shell::Command->new_from_brik_init($self) or return;
-   $command->as_matrix(0);
-   $command->as_array(0);
-   $command->capture_stderr(1);
+   my $sc = Metabrik::Shell::Command->new_from_brik_init($self) or return;
+   $sc->as_matrix(0);
+   $sc->as_array(0);
+   $sc->capture_stderr(1);
 
    my $cmd = "sysctl net.ipv4.conf.$device.forwarding";
-   chomp(my $line = $command->capture($cmd));
+   chomp(my $line = $sc->capture($cmd));
 
    $self->log->verbose("is_router_ipv4: cmd [$cmd]");
    $self->log->verbose("is_router_ipv4: returned [$line]");
@@ -187,17 +187,15 @@ sub enable_router_ipv4 {
    my ($device) = @_;
 
    $device ||= $self->device;
-   if (! defined($device)) {
-      return $self->log->error($self->brik_help_run('enable_router_ipv4'));
-   }
+   $self->brik_help_run_undef_arg('enable_router_ipv4', $device) or return;
 
-   my $command = Metabrik::Shell::Command->new_from_brik_init($self) or return;
-   $command->as_matrix(0);
-   $command->as_array(0);
-   $command->capture_stderr(1);
+   my $sc = Metabrik::Shell::Command->new_from_brik_init($self) or return;
+   $sc->as_matrix(0);
+   $sc->as_array(0);
+   $sc->capture_stderr(1);
 
    my $cmd = "sudo sysctl -w net.ipv4.conf.$device.forwarding=1";
-   chomp(my $line = $command->capture($cmd));
+   chomp(my $line = $sc->capture($cmd));
 
    $self->log->verbose("enable_router_ipv4: cmd [$cmd]"); 
    $self->log->verbose("enable_router_ipv4: returned [$line]");
@@ -216,17 +214,15 @@ sub disable_router_ipv4 {
    my ($device) = @_;
 
    $device ||= $self->device;
-   if (! defined($device)) {
-      return $self->log->error($self->brik_help_run('disable_router_ipv4'));
-   }
+   $self->brik_help_run_undef_arg('disable_router_ipv4', $device) or return;
 
-   my $command = Metabrik::Shell::Command->new_from_brik_init($self) or return;
-   $command->as_matrix(0);
-   $command->as_array(0);
-   $command->capture_stderr(1);
+   my $sc = Metabrik::Shell::Command->new_from_brik_init($self) or return;
+   $sc->as_matrix(0);
+   $sc->as_array(0);
+   $sc->capture_stderr(1);
 
    my $cmd = "sudo sysctl -w net.ipv4.conf.$device.forwarding=0";
-   chomp(my $line = $command->capture($cmd));
+   chomp(my $line = $sc->capture($cmd));
 
    $self->log->verbose("disable_router_ipv4: cmd [$cmd]");
    $self->log->verbose("disable_router_ipv4: returned [$line]");
@@ -250,7 +246,7 @@ Metabrik::Network::Route - network::route Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
