@@ -1,5 +1,5 @@
 #
-# $Id: S7comm.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: S7comm.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # network::s7comm Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik::Client::Tcp);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
-      tags => [ qw(unstable s7comm) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       commands => {
          probe => [ qw(host port|OPTIONAL) ],
       },
@@ -25,10 +27,7 @@ sub probe {
 
    $host ||= $self->host;
    $port ||= 102;
-
-   if (! defined($host)) {
-      return $self->log->error($self->brik_help_run('probe'));
-   }
+   $self->brik_help_run_undef_arg('probe', $host) or return;
 
    # To port 102/TCP (from plcscan)
    my $probe =
@@ -38,9 +37,9 @@ sub probe {
 
    $self->host($host);
    $self->port($port);
-   $self->connect or return $self->log->error("probe: connect failed");
-   $self->write($probe) or return $self->log->error("probe: write failed");
-   my $response = $self->read or return $self->log->error("probe: read failed");
+   $self->connect or return;
+   $self->write($probe) or return;
+   my $response = $self->read or return;
    $self->disconnect;
 
    return $response;
@@ -56,7 +55,7 @@ Metabrik::Network::S7comm - network::s7comm Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
