@@ -1,5 +1,5 @@
 #
-# $Id: Smtp.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Smtp.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # network::smtp Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
-      tags => [ qw(unstable network smtp) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          server => [ qw(server) ],
          port => [ qw(port) ],
@@ -23,7 +25,7 @@ sub brik_properties {
          port => 25,
       },
       commands => {
-         open => [ ],
+         open => [ qw(server|OPTIONAL port|OPTIONAL) ],
          close => [ ],
       },
       require_modules => {
@@ -34,16 +36,12 @@ sub brik_properties {
 
 sub open {
    my $self = shift;
+   my ($server, $port) = @_;
 
-   my $server = $self->server;
-   if (! defined($server)) {
-      return $self->log->error($self->brik_help_set('server'));
-   }
-
-   my $port = $self->port;
-   if (! defined($port)) {
-      return $self->log->error($self->brik_help_set('port'));
-   }
+   $server ||= $self->server;
+   $port ||= $self->port;
+   $self->brik_help_run_undef_arg('open', $server) or return;
+   $self->brik_help_run_undef_arg('open', $port) or return;
 
    my $smtp = Net::SMTP->new(
       $server,
@@ -78,7 +76,7 @@ Metabrik::Network::Smtp - network::smtp Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
