@@ -1,5 +1,5 @@
 #
-# $Id: Traceroute.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Traceroute.pm,v fc658e60fb76 2016/10/08 15:24:49 gomor $
 #
 # network::traceroute Brik
 #
@@ -12,7 +12,7 @@ use base qw(Metabrik::Shell::Command Metabrik::System::Package);
 # Default attribute values put here will BE inherited by subclasses
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
+      revision => '$Revision: fc658e60fb76 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -36,7 +36,8 @@ sub brik_properties {
          'tcptraceroute', => [ ],
       },
       need_packages => {
-         'ubuntu' => [ qw(tcptraceroute) ],
+         ubuntu => [ qw(tcptraceroute) ],
+         debian => [ qw(tcptraceroute) ],
       },
    };
 }
