@@ -1,5 +1,5 @@
 #
-# $Id: Http.pm,v a6e30d37450c 2015/03/16 06:08:27 gomor $
+# $Id: Http.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # proxy::http Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: a6e30d37450c $',
-      tags => [ qw(unstable proxy http) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          port => [ qw(integer) ],
          truncate_request => [ qw(integer) ],
@@ -34,9 +36,10 @@ sub brik_properties {
    };
 }
 
+#
 # XXX: see http://cpansearch.perl.org/src/MIKEM/Net-SSLeay-1.65/examples/https-proxy-snif.pl
 # XXX: for HTTPS mitm
-
+#
 sub requests {
    my $self = shift;
 
@@ -118,7 +121,7 @@ Metabrik::Proxy::Http - proxy::http Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
