@@ -1,5 +1,5 @@
 #
-# $Id: Ssh2tcp.pm,v cb06b0aa21d0 2015/11/07 18:01:20 gomor $
+# $Id: Ssh2tcp.pm,v 677135422623 2016/01/29 18:14:57 gomor $
 #
 # proxy::ssh2tcp Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik::System::Process);
 
 sub brik_properties {
    return {
-      revision => '$Revision: cb06b0aa21d0 $',
-      tags => [ qw(unstable proxy ssh tcp ssh2tcp socket netcat) ],
+      revision => '$Revision: 677135422623 $',
+      tags => [ qw(unstable ssh tcp socket netcat) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          hostname => [ qw(listen_hostname) ],
          port => [ qw(listen_port) ],
@@ -37,7 +39,6 @@ sub brik_properties {
       require_modules => {
          'Metabrik::Client::Openssh' => [ ],
          'Metabrik::Server::Tcp' => [ ],
-         'Metabrik::System::Process' => [ ],
       },
    };
 }
@@ -79,7 +80,7 @@ sub background_tunnel_loop {
    my $self = shift;
    my $args = \@_;
 
-   return $self->daemonize(sub { $self->start(@$args) && $self->tunnel_loop(@$args) });
+   return $self->start(sub { $self->start(@$args) && $self->tunnel_loop(@$args) });
 }
 
 sub start {
@@ -91,19 +92,17 @@ sub start {
    $ssh_hostname_port ||= $self->ssh_hostname_port;
    $remote_hostname_port ||= $self->remote_hostname_port;
    $username ||= $self->username;
-   if (! defined($ssh_hostname_port)) {
-      return $self->log->error($self->brik_help_run('start'));
-   }
-   if (! defined($remote_hostname_port)) {
-      return $self->log->error($self->brik_help_run('start'));
-   }
+   $self->brik_help_run_undef_arg('start', $ssh_hostname_port) or return;
+   my $ref = $self->brik_help_run_invalid_arg('start', $ssh_hostname_port, 'ARRAY', 'SCALAR')
+      or return;
+   $self->brik_help_run_undef_arg('start', $remote_hostname_port) or return;
    if ($remote_hostname_port !~ /^[^:]+:\d+$/) {
       return $self->log->error("start: invalid format for remote_hostname_port [$remote_hostname_port], must be hostname:port");
    }
 
    my $so;
    # Only one hop
-   if (! ref($ssh_hostname_port)) {
+   if ($ref eq 'SCALAR') {
       if ($ssh_hostname_port !~ /^[^:]+:\d+$/) {
          return $self->log->error("start: invalid format for ssh_hostname_port [$ssh_hostname_port], must be hostname:port");
       }
@@ -117,7 +116,7 @@ sub start {
       $self->log->verbose("start: connected to SSH [$ssh_hostname]:$ssh_port");
    }
    # Multiple hops :)
-   elsif (ref($ssh_hostname_port) eq 'ARRAY') {
+   elsif ($ref eq 'ARRAY') {
       my @ok = ();
       for my $this (@$ssh_hostname_port) {
          if ($this !~ /^[^:]+:\d+$/) {
@@ -214,9 +213,8 @@ sub tunnel_loop {
    if (! $self->is_started) {
       return $self->log->error($self->brik_help_run('start'));
    }
-   if (! defined($remote_hostname_port)) {
-      return $self->log->error($self->brik_help_run('tunnel_loop'));
-   }
+
+   $self->brik_help_run_undef_arg('tunnel_loop', $remote_hostname_port) or return;
    if ($remote_hostname_port !~ /^[^:]+:\d+$/) {
       return $self->log->error("start: invalid format for remote_hostname_port [$remote_hostname_port], must be hostname:port");
    }
@@ -342,7 +340,7 @@ Metabrik::Proxy::Ssh2tcp - proxy::ssh2tcp Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
