@@ -1,5 +1,5 @@
 #
-# $Id: Tcpdump.pm,v a90d4c65e3b6 2015/11/01 16:37:45 gomor $
+# $Id: Tcpdump.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # remote::tcpdump Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik::Client::Ssh);
 
 sub brik_properties {
    return {
-      revision => '$Revision: a90d4c65e3b6 $',
-      tags => [ qw(unstable tcpdump) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          device => [ qw(device) ],
          _started => [ qw(INTERNAL) ],
@@ -54,7 +56,7 @@ sub start {
    my $self = shift;
 
    if ($self->_started) {
-      return $self->log->verbose("already started");
+      return $self->log->verbose("start: already started");
    }
 
    $self->connect or return;
@@ -120,7 +122,7 @@ sub next {
 
    my $channel = $self->_channel;
    if (! defined($channel)) {
-      return $self->log->error("channel not found");
+      return $self->log->error("next: channel not found");
    }
 
    my $out = $self->_out;
@@ -150,7 +152,7 @@ sub nextall {
 
    my $channel = $self->_channel;
    if (! defined($channel)) {
-      return $self->log->error("channel not found");
+      return $self->log->error("nextall: channel not found");
    }
 
    my $out = $self->_out;
@@ -161,7 +163,7 @@ sub nextall {
    # If reader not already open, we open it
    my $dump = $self->_dump;
    if (! $dump->isRunning) {
-      $dump->start or return $self->log->error("unable to start pcap reader");
+      $dump->start or return $self->log->error("nextall: unable to start pcap reader");
    }
 
    my @next = ();
@@ -182,7 +184,7 @@ Metabrik::Remote::Tcpdump - remote::tcpdump Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
