@@ -1,5 +1,5 @@
 #
-# $Id: Rest.pm,v 5ff3fac424d5 2015/11/09 18:06:36 gomor $
+# $Id: Rest.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # server::rest Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik::Server::Http);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 5ff3fac424d5 $',
-      tags => [ qw(unstable server rest api) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable api) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          datadir => [ qw(datadir) ],
          hostname => [ qw(listen_hostname) ],
@@ -43,9 +45,10 @@ sub start {
    my $root = $self->datadir;
    $post_handlers ||= [];
    my $output_mode = $self->output_mode;
-   if (! defined($hostname) || ! defined($port) || ! defined($root) || ! defined($get_handlers)) {
-      return $self->log->error($self->brik_help_run('start'));
-   }
+   $self->brik_help_run_undef_arg('start', $hostname) or return;
+   $self->brik_help_run_undef_arg('start', $port) or return;
+   $self->brik_help_run_undef_arg('start', $root) or return;
+   $self->brik_help_run_undef_arg('start', $get_handlers) or return;
 
    my $http = HTTP::Server::Brick->new(
       port => $port,
@@ -72,7 +75,7 @@ sub start {
             my ($req, $res) = @_;
             my $hash = &{$get->{sub}}($req, $res) || {
                error => 1,
-               error_string => 'unknown'
+               error_string => 'undef'
             };
             $res->add_content($se->encode($hash));
             return 1;
@@ -97,7 +100,7 @@ Metabrik::Server::Rest - server::rest Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
