@@ -1,5 +1,5 @@
 #
-# $Id: Ascii.pm,v c6019afba057 2015/10/27 18:56:35 gomor $
+# $Id: Ascii.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # string::ascii Brik
 #
@@ -11,12 +11,12 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: c6019afba057 $',
-      tags => [ qw(unstable encode decode ascii) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable encode decode) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       commands => {
-         from_dec => [ qw($data) ],
-      },
-      require_modules => {
+         from_dec => [ qw(data|$data_list) ],
       },
    };
 }
@@ -25,12 +25,12 @@ sub from_dec {
    my $self = shift;
    my ($data) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('from_dec'));
-   }
+   $self->brik_help_run_undef_arg('from_dec', $data) or return;
+   my $ref = $self->brik_help_run_invalid_arg('from_dec', $data, 'ARRAY', 'SCALAR')
+      or return;
 
    my @data = ();
-   if (ref($data) eq 'ARRAY') {
+   if ($ref eq 'ARRAY') {
       for my $this (@$data) {
          if ($this =~ /^\d+$/) {
             push @data, $this;
@@ -40,7 +40,7 @@ sub from_dec {
          }
       }
    }
-   elsif (! ref($data)) {
+   else {
       if ($data =~ /^\d+$/) {
          push @data, $data;
       }
@@ -67,7 +67,7 @@ Metabrik::String::Ascii - string::ascii Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
