@@ -1,5 +1,5 @@
 #
-# $Id: Hexa.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Hexa.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # string::hexa Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
+      revision => '$Revision: 1cdea52670de $',
       tags => [ qw(unstable encode decode hex) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          with_x => [ ],
       },
@@ -34,9 +36,7 @@ sub encode {
    my $self = shift;
    my ($data) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('encode'));
-   }
+   $self->brik_help_run_undef_arg('encode', $data) or return;
 
    my $encoded = unpack('H*', $data);
 
@@ -51,9 +51,7 @@ sub decode {
    my $self = shift;
    my ($data) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('decode'));
-   }
+   $self->brik_help_run_undef_arg('decode', $data) or return;
 
    # Keep only hex-compliant characters
    $data =~ s/[^a-fA-F0-9]//g;
@@ -87,7 +85,7 @@ Metabrik::String::Hexa - string::hexa Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
