@@ -1,5 +1,5 @@
 #
-# $Id: Json.pm,v 037cb3d6d057 2015/11/21 09:41:00 gomor $
+# $Id: Json.pm,v 8618a4b46183 2016/03/19 16:37:47 gomor $
 #
 # string::json Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 037cb3d6d057 $',
-      tags => [ qw(unstable encode decode json) ],
+      revision => '$Revision: 8618a4b46183 $',
+      tags => [ qw(unstable encode decode) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       commands => {
          encode => [ qw($data_list|$data_hash) ],
          decode => [ qw($data) ],
@@ -27,13 +29,8 @@ sub encode {
    my $self = shift;
    my ($data) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('encode'));
-   }
-
-   if (ref($data) ne 'ARRAY' && ref($data) ne 'HASH') {
-      return $self->log->error("encode: you need to give data as an ARRAYREF or HASHREF");
-   }
+   $self->brik_help_run_undef_arg('encode', $data) or return;
+   $self->brik_help_run_invalid_arg('encode', $data, 'ARRAY', 'HASH') or return;
 
    my $encoded = '';
    eval {
@@ -51,13 +48,13 @@ sub decode {
    my $self = shift;
    my ($data) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('decode'));
-   }
+   $self->brik_help_run_undef_arg('decode', $data) or return;
 
    my $decoded = '';
    eval {
-      $decoded = JSON::XS::decode_json($data);
+      my $j = JSON::XS->new;
+      $j->relaxed(1);
+      $decoded = $j->decode($data);
    };
    if ($@) {
       chomp($@);
@@ -77,7 +74,7 @@ Metabrik::String::Json - string::json Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
