@@ -1,5 +1,5 @@
 #
-# $Id: Parse.pm,v 887d85a7f604 2015/11/12 14:44:58 gomor $
+# $Id: Parse.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # string::parse Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 887d85a7f604 $',
-      tags => [ qw(unstable parse string) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       commands => {
          identify => [ qw(string) ],
          to_array => [ qw($data) ],
@@ -26,13 +28,8 @@ sub to_array {
    my $self = shift;
    my ($data) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('to_array'));
-   }
-
-   if (ref($data)) {
-      return $self->log->error("to_array: data must be a SCALAR");
-   }
+   $self->brik_help_run_undef_arg('to_array', $data) or return;
+   $self->brik_help_run_invalid_arg('to_array', $data, 'SCALAR') or return;
 
    my @array = split(/\n/, $data);
 
@@ -43,9 +40,7 @@ sub to_matrix {
    my $self = shift;
    my ($data) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('to_matrix'));
-   }
+   $self->brik_help_run_undef_arg('to_matrix', $data) or return;
 
    my $array = $self->to_array($data) or return;
 
@@ -61,9 +56,7 @@ sub identify {
    my $self = shift;
    my ($string) = @_;
 
-   if (! defined($string)) {
-      return $self->log->error($self->brik_help_run('identify'));
-   }
+   $self->brik_help_run_undef_arg('identify', $string) or return;
 
    my $length = length($string);
    # Truncate to 128 Bytes
@@ -100,13 +93,8 @@ sub split_by_blank_line {
    my $self = shift;
    my ($data) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('split_by_blank_line'));
-   }
-
-   if (ref($data) ne 'ARRAY') {
-      return $self->log->error("split_by_blank_line: data must be an ARRAYREF");
-   }
+   $self->brik_help_run_undef_arg('split_by_blank_line', $data) or return;
+   $self->brik_help_run_invalid_arg('split_by_blank_line', $data, 'ARRAY') or return;
 
    my $new = [];
    my @chunks = ();
@@ -137,7 +125,7 @@ Metabrik::String::Parse - string::parse Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
