@@ -1,5 +1,5 @@
 #
-# $Id: Random.pm,v 14a5b315905e 2015/01/08 07:00:53 gomor $
+# $Id: Random.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # string::random Brik
 #
@@ -11,10 +11,14 @@ use base qw(Metabrik::String::Password);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 14a5b315905e $',
-      tags => [ qw(unstable string random) ],
-      attributes_default => {
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
+      attributes => {
          datadir => [ qw(datadir) ],
+      },
+      attributes_default => {
          charset => [ 'A'..'K', 'M'..'Z', 'a'..'k', 'm'..'z', 2..9, '_', '-' ],
          length => 20,
          count => 1,
@@ -46,7 +50,7 @@ Metabrik::String::Random - string::random Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
