@@ -1,5 +1,5 @@
 #
-# $Id: Syslog.pm,v 21a3474f0288 2016/02/11 07:07:00 gomor $
+# $Id: Syslog.pm,v b5a7d96de9f1 2016/10/11 06:17:23 gomor $
 #
 # string::syslog Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 21a3474f0288 $',
+      revision => '$Revision: b5a7d96de9f1 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -20,10 +20,12 @@ sub brik_properties {
          hostname => [ qw(hostname) ],
          process => [ qw(name) ],
          pid => [ qw(id) ],
+         do_rfc3164 => [ qw(0|1) ],
       },
       attributes_default => {
          process => 'metabrik',
-         pid => '0',
+         pid => $$,
+         do_rfc3164 => 0,
       },
       commands => {
          encode => [ qw($data hostname|OPTIONAL process|OPTIONAL pid|OPTIONAL) ],
@@ -70,7 +72,15 @@ sub encode {
       ':'.
       (($time[0] < 10) ? ('0'.$time[0]) : $time[0]);
 
-   return "$timestamp $hostname $process\[$pid\]: $data";
+   my $message = '';
+   if ($self->do_rfc3164) {
+      $message = "$timestamp $hostname $process\[$pid\]: $data";
+   }
+   else {
+      $message = "$process\[$pid\]: $data";
+   }
+
+   return $message;
 }
 
 sub decode {
