@@ -1,5 +1,5 @@
 #
-# $Id: Uri.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Uri.pm,v e6459cc4d06c 2016/09/17 16:14:53 gomor $
 #
 # string::uri Brik
 #
@@ -11,8 +11,8 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
-      tags => [ qw(unstable) ],
+      revision => '$Revision: e6459cc4d06c $',
+      tags => [ qw(unstable encode decode escape) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
