@@ -1,5 +1,5 @@
 #
-# $Id: Package.pm,v 7d4af34f011c 2016/04/12 05:55:37 gomor $
+# $Id: Package.pm,v f43f03db50ed 2016/10/04 05:00:14 gomor $
 #
 # system::freebsd::package Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Shell::Command);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 7d4af34f011c $',
+      revision => '$Revision: f43f03db50ed $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -24,7 +24,7 @@ sub brik_properties {
          is_installed => [ qw(package|$package_list) ],
          which => [ qw(file) ],
          system_update => [ ],
-         system_upgrade => [ ],
+         system_upgrade => [ qw(RELEASE|OPTIONAL) ],
       },
       require_binaries => {
          'pkg' => [ ],
@@ -124,8 +124,17 @@ sub system_update {
 
 sub system_upgrade {
    my $self = shift;
+   my ($release) = @_;
+
+   my $cmd = 'freebsd-update';
+   if (defined($release)) {
+      $cmd .= ' upgrade -r '.$release;
+      # We should also run a freebsd-update install after that
+   }
+   else {
+      $cmd .= ' install';
+   }
 
-   my $cmd = 'freebsd-update install';
 
    return $self->sudo_system($cmd);
 }
