@@ -1,5 +1,5 @@
 #
-# $Id: Package.pm,v 3245fde389ac 2016/02/20 10:23:37 gomor $
+# $Id: Package.pm,v f43f03db50ed 2016/10/04 05:00:14 gomor $
 #
 # system::package Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 3245fde389ac $',
+      revision => '$Revision: f43f03db50ed $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -20,16 +20,16 @@ sub brik_properties {
          search => [ qw(string) ],
          install => [ qw(package|$package_list) ],
          remove => [ qw(package|$package_list) ],
-         update => [ ],
-         upgrade => [ ],
+         update => [ qw(version|OPTIONAL) ],
+         upgrade => [ qw(version|OPTIONAL) ],
          is_os => [ qw(os) ],
          is_os_ubuntu => [ ],
          is_os_freebsd => [ ],
          is_installed => [ qw(package|$package_list) ],
          my_os => [ ],
          which => [ qw(file) ],
-         system_update => [ ],
-         system_upgrade => [ ],
+         system_update => [ qw(version|OPTIONAL) ],
+         system_upgrade => [ qw(version|OPTIONAL) ],
       },
       require_modules => {
          'Metabrik::System::Os' => [ ],
@@ -111,7 +111,7 @@ sub update {
 
    my $sp = $self->get_system_package or return;
 
-   return $sp->update;
+   return $sp->update(@_);
 }
 
 sub upgrade {
@@ -119,7 +119,7 @@ sub upgrade {
 
    my $sp = $self->get_system_package or return;
 
-   return $sp->upgrade;
+   return $sp->upgrade(@_);
 }
 
 sub system_update {
@@ -127,7 +127,7 @@ sub system_update {
 
    my $sp = $self->get_system_package or return;
 
-   return $sp->system_update;
+   return $sp->system_update(@_);
 }
 
 sub system_upgrade {
@@ -135,7 +135,7 @@ sub system_upgrade {
 
    my $sp = $self->get_system_package or return;
 
-   return $sp->system_upgrade;
+   return $sp->system_upgrade(@_);
 }
 
 sub list {
