@@ -1,5 +1,5 @@
 #
-# $Id: Universal.pm,v 811ac7ccde81 2016/02/22 18:15:08 gomor $
+# $Id: Universal.pm,v 23fded51e1d7 2016/04/05 05:07:55 gomor $
 #
 # time::universal Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 811ac7ccde81 $',
+      revision => '$Revision: 23fded51e1d7 $',
       tags => [ qw(unstable timezone) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -28,7 +28,11 @@ sub brik_properties {
          search_timezone => [ qw(string) ],
          localtime => [ qw(timezone|OPTIONAL) ],
          today => [ qw(separator|OPTIONAL) ],
+         yesterday => [ qw(separator|OPTIONAL) ],
          date => [ ],
+         month => [ qw(timezone|OPTIONAL) ],
+         last_month => [ qw(timezone|OPTIONAL) ],
+         is_timezone => [ qw(timezone) ],
       },
       require_modules => {
          'DateTime' => [ ],
@@ -71,6 +75,10 @@ sub localtime {
    my $time = {};
    if (ref($timezone) eq 'ARRAY') {
       for my $tz (@$timezone) {
+         if (! $self->is_timezone($tz)) {
+            $self->log->warning("localtime: invalid timezone [$timezone]");
+            next;
+         }
          my $dt = DateTime->now(
             time_zone => $tz,
          );
@@ -78,6 +86,9 @@ sub localtime {
       }
    }
    else {
+      if (! $self->is_timezone($timezone)) {
+         return $self->log->error("localtime: invalid timezone [$timezone]");
+      }
       my $dt = DateTime->now(
          time_zone => $timezone,
       );
@@ -101,12 +112,69 @@ sub today {
    return sprintf("%04d$sep%02d$sep%02d", $y, $m, $d);
 }
 
+sub yesterday {
+   my $self = shift;
+   my ($sep) = @_;
+
+   $sep ||= $self->separator;
+
+   my @a = CORE::localtime(time() - (24 * 3600));
+   my $y = $a[5] + 1900;
+   my $m = $a[4] + 1;
+   my $d = $a[3];
+
+   return sprintf("%04d$sep%02d$sep%02d", $y, $m, $d);
+}
+
 sub date {
    my $self = shift;
 
    return CORE::localtime()."";
 }
 
+sub month {
+   my $self = shift;
+   my ($sep) = @_;
+
+   $sep ||= $self->separator;
+
+   my @a = CORE::localtime();
+   my $y = $a[5] + 1900;
+   my $m = $a[4] + 1;
+
+   return sprintf("%04d$sep%02d", $y, $m);
+}
+
+sub last_month {
+   my $self = shift;
+   my ($sep) = @_;
+
+   $sep ||= $self->separator;
+
+   my @a = CORE::localtime();
+   my $y = $a[5] + 1900;
+   my $m = $a[4];
+
+   if ($m == 0) {
+      $m = 12;
+      $y -= 1;
+   }
+
+   return sprintf("%04d$sep%02d", $y, $m);
+}
+
+sub is_timezone {
+   my $self = shift;
+   my ($tz) = @_;
+
+   $self->brik_help_run_undef_arg('is_timezone', $tz) or return;
+
+   my $tz_list = $self->list_timezones;
+   my %h = map { $_ => 1 } @$tz_list;
+
+   return exists($h{$tz}) ? 1 : 0;
+}
+
 1;
 
 __END__
