@@ -1,5 +1,5 @@
 #
-# $Id: Screenshot.pm,v a1d025d2b3b9 2016/02/22 18:54:32 gomor $
+# $Id: Screenshot.pm,v fc658e60fb76 2016/10/08 15:24:49 gomor $
 #
 # xorg::screenshot Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Shell::Command Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: a1d025d2b3b9 $',
+      revision => '$Revision: fc658e60fb76 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -45,7 +45,8 @@ sub brik_properties {
          'scrot' => [ ],
       },
       need_packages => {
-         'ubuntu' => [ qw(imagemagick scrot) ],
+         ubuntu => [ qw(imagemagick scrot) ],
+         debian => [ qw(imagemagick scrot) ],
       },
    };
 }
